@@ -90,6 +90,10 @@ public:
 
   bool IsInlined() const;
 
+  bool IsArtificial();
+
+  bool IsArtificial() const;
+
   /// The version that doesn't supply a 'use_dynamic' value will use the
   /// target's default.
   lldb::SBValue EvaluateExpression(const char *expr);
@@ -153,10 +157,10 @@ public:
                              lldb::DynamicValueType use_dynamic);
 
   // Find a value for a variable expression path like "rect.origin.x" or
-  // "pt_ptr->x", "*self", "*this->obj_ptr". The returned value is _not_
-  // and expression result and is not a constant object like
-  // SBFrame::EvaluateExpression(...) returns, but a child object of
-  // the variable value.
+  // "pt_ptr->x", "*self", "*this->obj_ptr". The returned value is _not_ and
+  // expression result and is not a constant object like
+  // SBFrame::EvaluateExpression(...) returns, but a child object of the
+  // variable value.
   lldb::SBValue GetValueForVariablePath(const char *var_expr_cstr,
                                         DynamicValueType use_dynamic);
 
