@@ -10,14 +10,11 @@
 #ifndef liblldb_BreakpointOptions_h_
 #define liblldb_BreakpointOptions_h_
 
-// C Includes
-// C++ Includes
 #include <memory>
 #include <string>
 
-// Other libraries and framework includes
-// Project includes
 #include "lldb/Utility/Baton.h"
+#include "lldb/Utility/Flags.h"
 #include "lldb/Utility/StringList.h"
 #include "lldb/Utility/StructuredData.h"
 #include "lldb/lldb-private.h"
@@ -26,13 +23,28 @@ namespace lldb_private {
 
 //----------------------------------------------------------------------
 /// @class BreakpointOptions BreakpointOptions.h
-/// "lldb/Breakpoint/BreakpointOptions.h"
-/// @brief Class that manages the options on a breakpoint or breakpoint
-/// location.
+/// "lldb/Breakpoint/BreakpointOptions.h" Class that manages the options on a
+/// breakpoint or breakpoint location.
 //----------------------------------------------------------------------
 
 class BreakpointOptions {
+friend class BreakpointLocation;
+friend class BreakpointName;
+friend class lldb_private::BreakpointOptionGroup;
+friend class Breakpoint;
+
 public:
+  enum OptionKind {
+    eCallback     = 1 << 0,
+    eEnabled      = 1 << 1,
+    eOneShot      = 1 << 2,
+    eIgnoreCount  = 1 << 3,
+    eThreadSpec   = 1 << 4,
+    eCondition    = 1 << 5,
+    eAutoContinue = 1 << 6,
+    eAllOptions   = (eCallback | eEnabled | eOneShot | eIgnoreCount | eThreadSpec
+                     | eCondition | eAutoContinue)
+  };
   struct CommandData {
     CommandData()
         : user_source(), script_source(),
@@ -87,19 +99,10 @@ public:
   //------------------------------------------------------------------
   // Constructors and Destructors
   //------------------------------------------------------------------
-  //------------------------------------------------------------------
-  /// Default constructor.  The breakpoint is enabled, and has no condition,
-  /// callback, ignore count, etc...
-  //------------------------------------------------------------------
-  BreakpointOptions();
-  BreakpointOptions(const BreakpointOptions &rhs);
-
-  static BreakpointOptions *CopyOptionsNoCallback(BreakpointOptions &rhs);
 
   //------------------------------------------------------------------
-  /// This constructor allows you to specify all the breakpoint options
-  /// except the callback.  That one is more complicated, and better
-  /// to do by hand.
+  /// This constructor allows you to specify all the breakpoint options except
+  /// the callback.  That one is more complicated, and better to do by hand.
   ///
   /// @param[in] condition
   ///    The expression which if it evaluates to \b true if we are to stop
@@ -112,7 +115,15 @@ public:
   ///
   //------------------------------------------------------------------
   BreakpointOptions(const char *condition, bool enabled = true,
-                    int32_t ignore = 0, bool one_shot = false);
+                    int32_t ignore = 0, bool one_shot = false,
+                    bool auto_continue = false);
+
+  //------------------------------------------------------------------
+  /// Breakpoints make options with all flags set.  Locations and Names make
+  /// options with no flags set.
+  //------------------------------------------------------------------
+  BreakpointOptions(bool all_flags_set);
+  BreakpointOptions(const BreakpointOptions &rhs);
 
   virtual ~BreakpointOptions();
 
@@ -129,23 +140,26 @@ public:
   // Operators
   //------------------------------------------------------------------
   const BreakpointOptions &operator=(const BreakpointOptions &rhs);
+  
+  //------------------------------------------------------------------
+  /// Copy over only the options set in the incoming BreakpointOptions.
+  //------------------------------------------------------------------
+  void CopyOverSetOptions(const BreakpointOptions &rhs);
 
   //------------------------------------------------------------------
   // Callbacks
   //
   // Breakpoint callbacks come in two forms, synchronous and asynchronous.
-  // Synchronous callbacks will get
-  // run before any of the thread plans are consulted, and if they return false
-  // the target will continue
-  // "under the radar" of the thread plans.  There are a couple of restrictions
-  // to synchronous callbacks:
-  // 1) They should NOT resume the target themselves.  Just return false if you
-  // want the target to restart.
-  // 2) Breakpoints with synchronous callbacks can't have conditions (or rather,
-  // they can have them, but they
-  //    won't do anything.  Ditto with ignore counts, etc...  You are supposed
-  //    to control that all through the
-  //    callback.
+  // Synchronous callbacks will get run before any of the thread plans are
+  // consulted, and if they return false the target will continue "under the
+  // radar" of the thread plans.  There are a couple of restrictions to
+  // synchronous callbacks:
+  // 1) They should NOT resume the target themselves.
+  //     Just return false if you want the target to restart.
+  // 2) Breakpoints with synchronous callbacks can't have conditions
+  //    (or rather, they can have them, but they won't do anything.
+  //    Ditto with ignore counts, etc...  You are supposed to control that all
+  //    through the callback.
   // Asynchronous callbacks get run as part of the "ShouldStop" logic in the
   // thread plan.  The logic there is:
   //   a) If the breakpoint is thread specific and not for this thread, continue
@@ -159,12 +173,10 @@ public:
   //   b) If the ignore count says we shouldn't stop, then ditto.
   //   c) If the condition says we shouldn't stop, then ditto.
   //   d) Otherwise, the callback will get run, and if it returns true we will
-  //   stop, and if false we won't.
+  //      stop, and if false we won't.
   //  The asynchronous callback can run the target itself, but at present that
-  //  should be the last action the
-  //  callback does.  We will relax this condition at some point, but it will
-  //  take a bit of plumbing to get
-  //  that to work.
+  //  should be the last action the callback does.  We will relax this condition
+  //  at some point, but it will take a bit of plumbing to get that to work.
   //
   //------------------------------------------------------------------
 
@@ -205,8 +217,8 @@ public:
   //------------------------------------------------------------------
   void ClearCallback();
 
-  // The rest of these functions are meant to be used only within the breakpoint
-  // handling mechanism.
+  // The rest of these functions are meant to be used only within the
+  // breakpoint handling mechanism.
 
   //------------------------------------------------------------------
   /// Use this function to invoke the callback for a specific stop.
@@ -290,7 +302,25 @@ public:
   //------------------------------------------------------------------
   /// If \a enable is \b true, enable the breakpoint, if \b false disable it.
   //------------------------------------------------------------------
-  void SetEnabled(bool enabled) { m_enabled = enabled; }
+  void SetEnabled(bool enabled) { 
+    m_enabled = enabled;
+    m_set_flags.Set(eEnabled);
+  }
+
+  //------------------------------------------------------------------
+  /// Check the auto-continue state.
+  /// @return
+  ///     \b true if the breakpoint is set to auto-continue, \b false otherwise.
+  //------------------------------------------------------------------
+  bool IsAutoContinue() const { return m_auto_continue; }
+
+  //------------------------------------------------------------------
+  /// Set the auto-continue state.
+  //------------------------------------------------------------------
+  void SetAutoContinue(bool auto_continue) { 
+    m_auto_continue = auto_continue;
+    m_set_flags.Set(eAutoContinue);
+  }
 
   //------------------------------------------------------------------
   /// Check the One-shot state.
@@ -302,7 +332,10 @@ public:
   //------------------------------------------------------------------
   /// If \a enable is \b true, enable the breakpoint, if \b false disable it.
   //------------------------------------------------------------------
-  void SetOneShot(bool one_shot) { m_one_shot = one_shot; }
+  void SetOneShot(bool one_shot) { 
+    m_one_shot = one_shot; 
+    m_set_flags.Set(eOneShot); 
+  }
 
   //------------------------------------------------------------------
   /// Set the breakpoint to ignore the next \a count breakpoint hits.
@@ -310,7 +343,10 @@ public:
   ///    The number of breakpoint hits to ignore.
   //------------------------------------------------------------------
 
-  void SetIgnoreCount(uint32_t n) { m_ignore_count = n; }
+  void SetIgnoreCount(uint32_t n) { 
+    m_ignore_count = n; 
+    m_set_flags.Set(eIgnoreCount);
+  }
 
   //------------------------------------------------------------------
   /// Return the current Ignore Count.
@@ -321,8 +357,7 @@ public:
 
   //------------------------------------------------------------------
   /// Return the current thread spec for this option. This will return nullptr
-  /// if the no thread
-  /// specifications have been set for this Option yet.
+  /// if the no thread specifications have been set for this Option yet.
   /// @return
   ///     The thread specification pointer for this option, or nullptr if none
   ///     has
@@ -331,8 +366,8 @@ public:
   const ThreadSpec *GetThreadSpecNoCreate() const;
 
   //------------------------------------------------------------------
-  /// Returns a pointer to the ThreadSpec for this option, creating it.
-  /// if it hasn't been created already.   This API is used for setting the
+  /// Returns a pointer to the ThreadSpec for this option, creating it. if it
+  /// hasn't been created already.   This API is used for setting the
   /// ThreadSpec items for this option.
   //------------------------------------------------------------------
   ThreadSpec *GetThreadSpec();
@@ -354,22 +389,34 @@ public:
                            lldb::user_id_t break_loc_id);
 
   //------------------------------------------------------------------
-  /// Set a callback based on BreakpointOptions::CommandData.
-  /// @param[in] cmd_data
+  /// Set a callback based on BreakpointOptions::CommandData. @param[in]
+  /// cmd_data
   ///     A UP holding the new'ed CommandData object.
   ///     The breakpoint will take ownership of pointer held by this object.
   //------------------------------------------------------------------
   void SetCommandDataCallback(std::unique_ptr<CommandData> &cmd_data);
-
+  
+  void Clear();
+  
+  bool AnySet() const {
+    return m_set_flags.AnySet(eAllOptions);
+  }
+  
 protected:
-  //------------------------------------------------------------------
+//------------------------------------------------------------------
   // Classes that inherit from BreakpointOptions can see and modify these
   //------------------------------------------------------------------
+  bool IsOptionSet(OptionKind kind)
+  {
+    return m_set_flags.Test(kind);
+  }
+
   enum class OptionNames {
     ConditionText = 0,
     IgnoreCount,
     EnabledState,
     OneShotState,
+    AutoContinue,
     LastOptionName
   };
   static const char *g_option_names[(size_t)OptionNames::LastOptionName];
@@ -400,6 +447,9 @@ private:
   std::string m_condition_text; // The condition to test.
   size_t m_condition_text_hash; // Its hash, so that locations know when the
                                 // condition is updated.
+  bool m_auto_continue;         // If set, auto-continue from breakpoint.
+  Flags m_set_flags;            // Which options are set at this level.  Drawn
+                                // from BreakpointOptions::SetOptionsFlags.
 };
 
 } // namespace lldb_private
