@@ -11,11 +11,7 @@
 #ifndef liblldb_BreakpointResolverFileRegex_h_
 #define liblldb_BreakpointResolverFileRegex_h_
 
-// C Includes
-// C++ Includes
 #include <set>
-// Other libraries and framework includes
-// Project includes
 #include "lldb/Breakpoint/BreakpointResolver.h"
 #include "lldb/Utility/ConstString.h"
 
@@ -23,9 +19,8 @@ namespace lldb_private {
 
 //----------------------------------------------------------------------
 /// @class BreakpointResolverFileRegex BreakpointResolverFileRegex.h
-/// "lldb/Breakpoint/BreakpointResolverFileRegex.h"
-/// @brief This class sets breakpoints by file and line.  Optionally, it will
-/// look for inlined
+/// "lldb/Breakpoint/BreakpointResolverFileRegex.h" This class sets
+/// breakpoints by file and line.  Optionally, it will look for inlined
 /// instances of the file and line specification.
 //----------------------------------------------------------------------
 
@@ -48,7 +43,7 @@ public:
                                           SymbolContext &context, Address *addr,
                                           bool containing) override;
 
-  Searcher::Depth GetDepth() override;
+  lldb::SearchDepth GetDepth() override;
 
   void GetDescription(Stream *s) override;
 
