@@ -10,13 +10,13 @@
 #ifndef liblldb_Address_h_
 #define liblldb_Address_h_
 
-#include "lldb/lldb-defines.h"      // for LLDB_INVALID_ADDRESS
-#include "lldb/lldb-forward.h"      // for SectionWP, SectionSP, ModuleSP
-#include "lldb/lldb-private-enumerations.h" // for AddressClass
-#include "lldb/lldb-types.h"        // for addr_t
+#include "lldb/lldb-defines.h"
+#include "lldb/lldb-forward.h"
+#include "lldb/lldb-private-enumerations.h"
+#include "lldb/lldb-types.h"
 
-#include <stddef.h> // for size_t
-#include <stdint.h> // for uint32_t, UINT32_MAX, int64_t
+#include <stddef.h>
+#include <stdint.h>
 
 namespace lldb_private {
 class Block;
@@ -508,9 +508,9 @@ public:
   ///
   /// @see SymbolContextScope::CalculateSymbolContext(SymbolContext*)
   //------------------------------------------------------------------
-  uint32_t CalculateSymbolContext(
-      SymbolContext *sc,
-      uint32_t resolve_scope = lldb::eSymbolContextEverything) const;
+  uint32_t CalculateSymbolContext(SymbolContext *sc,
+                                  lldb::SymbolContextItem resolve_scope =
+                                      lldb::eSymbolContextEverything) const;
 
   lldb::ModuleSP CalculateSymbolContextModule() const;
 
