@@ -11,9 +11,8 @@
 #define liblldb_ValueObject_h_
 
 #include "lldb/Core/Value.h"
-#include "lldb/DataFormatters/DumpValueObjectOptions.h" // for DumpValueObj...
 #include "lldb/Symbol/CompilerType.h"
-#include "lldb/Symbol/Type.h" // for TypeImpl
+#include "lldb/Symbol/Type.h"
 #include "lldb/Target/ExecutionContext.h"
 #include "lldb/Target/Process.h"
 #include "lldb/Utility/ConstString.h"
@@ -21,30 +20,33 @@
 #include "lldb/Utility/SharedCluster.h"
 #include "lldb/Utility/Status.h"
 #include "lldb/Utility/UserID.h"
-#include "lldb/lldb-defines.h"              // for LLDB_INVALID...
-#include "lldb/lldb-enumerations.h"         // for DynamicValue...
-#include "lldb/lldb-forward.h"              // for ValueObjectSP
-#include "lldb/lldb-private-enumerations.h" // for AddressType
-#include "lldb/lldb-types.h"                // for addr_t, offs...
+#include "lldb/lldb-defines.h"
+#include "lldb/lldb-enumerations.h"
+#include "lldb/lldb-forward.h"
+#include "lldb/lldb-private-enumerations.h"
+#include "lldb/lldb-types.h"
 
 #include "llvm/ADT/ArrayRef.h"
 #include "llvm/ADT/Optional.h"
 #include "llvm/ADT/SmallVector.h"
-#include "llvm/ADT/StringRef.h" // for StringRef
+#include "llvm/ADT/StringRef.h"
 
 #include <functional>
 #include <initializer_list>
 #include <map>
-#include <mutex>   // for recursive_mutex
-#include <string>  // for string
-#include <utility> // for pair
+#include <mutex>
+#include <string>
+#include <utility>
 
-#include <stddef.h> // for size_t
-#include <stdint.h> // for uint32_t
+#include <stddef.h>
+#include <stdint.h>
 namespace lldb_private {
 class Declaration;
 }
 namespace lldb_private {
+class DumpValueObjectOptions;
+}
+namespace lldb_private {
 class EvaluateExpressionOptions;
 }
 namespace lldb_private {
@@ -286,10 +288,10 @@ public:
       return m_exe_ctx_ref;
     }
 
-    // Set the EvaluationPoint to the values in exe_scope,
-    // Return true if the Evaluation Point changed.
-    // Since the ExecutionContextScope is always going to be valid currently,
-    // the Updated Context will also always be valid.
+    // Set the EvaluationPoint to the values in exe_scope, Return true if the
+    // Evaluation Point changed. Since the ExecutionContextScope is always
+    // going to be valid currently, the Updated Context will also always be
+    // valid.
 
     //        bool
     //        SetContext (ExecutionContextScope *exe_scope);
@@ -327,8 +329,7 @@ public:
 
     void SetInvalid() {
       // Use the stop id to mark us as invalid, leave the thread id and the
-      // stack id around for logging and
-      // history purposes.
+      // stack id around for logging and history purposes.
       m_mod_id.SetInvalid();
 
       // Can't update an invalid state.
@@ -464,17 +465,16 @@ public:
 
   virtual bool SetValueFromCString(const char *value_str, Status &error);
 
-  // Return the module associated with this value object in case the
-  // value is from an executable file and might have its data in
-  // sections of the file. This can be used for variables.
+  // Return the module associated with this value object in case the value is
+  // from an executable file and might have its data in sections of the file.
+  // This can be used for variables.
   virtual lldb::ModuleSP GetModule();
 
   ValueObject *GetRoot();
 
   // Given a ValueObject, loop over itself and its parent, and its parent's
-  // parent, ..
-  // until either the given callback returns false, or you end up at a null
-  // pointer
+  // parent, .. until either the given callback returns false, or you end up at
+  // a null pointer
   ValueObject *FollowParentChain(std::function<bool(ValueObject *)>);
 
   virtual bool GetDeclaration(Declaration &decl);
@@ -517,9 +517,9 @@ public:
 
   virtual bool ResolveValue(Scalar &scalar);
 
-  // return 'false' whenever you set the error, otherwise
-  // callers may assume true means everything is OK - this will
-  // break breakpoint conditions among potentially a few others
+  // return 'false' whenever you set the error, otherwise callers may assume
+  // true means everything is OK - this will break breakpoint conditions among
+  // potentially a few others
   virtual bool IsLogicalTrue(Status &error);
 
   virtual const char *GetLocationAsCString();
@@ -635,9 +635,6 @@ public:
   virtual void SetLiveAddress(lldb::addr_t addr = LLDB_INVALID_ADDRESS,
                               AddressType address_type = eAddressTypeLoad) {}
 
-  // Find the address of the C++ vtable pointer
-  virtual lldb::addr_t GetCPPVTableAddress(AddressType &address_type);
-
   virtual lldb::ValueObjectSP Cast(const CompilerType &compiler_type);
 
   virtual lldb::ValueObjectSP CastPointerType(const char *name,
@@ -646,8 +643,8 @@ public:
   virtual lldb::ValueObjectSP CastPointerType(const char *name,
                                               lldb::TypeSP &type_sp);
 
-  // The backing bits of this value object were updated, clear any
-  // descriptive string, so we know we have to refetch them
+  // The backing bits of this value object were updated, clear any descriptive
+  // string, so we know we have to refetch them
   virtual void ValueUpdated() {
     ClearUserVisibleData(eClearUserVisibleDataItemsValue |
                          eClearUserVisibleDataItemsSummary |
@@ -694,9 +691,8 @@ public:
 
   lldb::ValueObjectSP Persist();
 
-  // returns true if this is a char* or a char[]
-  // if it is a char* and check_pointer is true,
-  // it also checks that the pointer is valid
+  // returns true if this is a char* or a char[] if it is a char* and
+  // check_pointer is true, it also checks that the pointer is valid
   bool IsCStringContainer(bool check_pointer = false);
 
   std::pair<size_t, bool>
@@ -776,11 +772,9 @@ public:
   }
 
   // Use GetParent for display purposes, but if you want to tell the parent to
-  // update itself
-  // then use m_parent.  The ValueObjectDynamicValue's parent is not the correct
-  // parent for
-  // displaying, they are really siblings, so for display it needs to route
-  // through to its grandparent.
+  // update itself then use m_parent.  The ValueObjectDynamicValue's parent is
+  // not the correct parent for displaying, they are really siblings, so for
+  // display it needs to route through to its grandparent.
   virtual ValueObject *GetParent() { return m_parent; }
 
   virtual const ValueObject *GetParent() const { return m_parent; }
@@ -904,9 +898,9 @@ protected:
   ValueObjectManager *m_manager; // This object is managed by the root object
                                  // (any ValueObject that gets created
   // without a parent.)  The manager gets passed through all the generations of
-  // dependent objects, and will keep the whole cluster of objects alive as long
-  // as a shared pointer to any of them has been handed out.  Shared pointers to
-  // value objects must always be made with the GetSP method.
+  // dependent objects, and will keep the whole cluster of objects alive as
+  // long as a shared pointer to any of them has been handed out.  Shared
+  // pointers to value objects must always be made with the GetSP method.
 
   ChildrenManager m_children;
   std::map<ConstString, ValueObject *> m_synthetic_children;
@@ -954,21 +948,19 @@ protected:
   // Constructors and Destructors
   //------------------------------------------------------------------
 
-  // Use the no-argument constructor to make a constant variable object (with no
-  // ExecutionContextScope.)
+  // Use the no-argument constructor to make a constant variable object (with
+  // no ExecutionContextScope.)
 
   ValueObject();
 
   // Use this constructor to create a "root variable object".  The ValueObject
-  // will be locked to this context
-  // through-out its lifespan.
+  // will be locked to this context through-out its lifespan.
 
   ValueObject(ExecutionContextScope *exe_scope,
               AddressType child_ptr_or_ref_addr_type = eAddressTypeLoad);
 
   // Use this constructor to create a ValueObject owned by another ValueObject.
-  // It will inherit the ExecutionContext
-  // of its parent.
+  // It will inherit the ExecutionContext of its parent.
 
   ValueObject(ValueObject &parent);
 
@@ -990,8 +982,8 @@ protected:
 
   virtual void CalculateSyntheticValue(bool use_synthetic = true);
 
-  // Should only be called by ValueObject::GetChildAtIndex()
-  // Returns a ValueObject managed by this ValueObject's manager.
+  // Should only be called by ValueObject::GetChildAtIndex() Returns a
+  // ValueObject managed by this ValueObject's manager.
   virtual ValueObject *CreateChildAtIndex(size_t idx,
                                           bool synthetic_array_member,
                                           int32_t synthetic_index);
@@ -1043,8 +1035,9 @@ private:
 //------------------------------------------------------------------------------
 // A value object manager class that is seeded with the static variable value
 // and it vends the user facing value object. If the type is dynamic it can
-// vend the dynamic type. If this user type also has a synthetic type associated
-// with it, it will vend the synthetic type. The class watches the process' stop
+// vend the dynamic type. If this user type also has a synthetic type
+// associated with it, it will vend the synthetic type. The class watches the
+// process' stop
 // ID and will update the user type when needed.
 //------------------------------------------------------------------------------
 class ValueObjectManager {
