@@ -11,13 +11,13 @@
 #define liblldb_ValueObjectCast_h_
 
 #include "lldb/Core/ValueObject.h"
-#include "lldb/Symbol/CompilerType.h" // for CompilerType
-#include "lldb/lldb-defines.h"        // for DISALLOW_COPY_AND_ASSIGN
-#include "lldb/lldb-enumerations.h"   // for ValueType
-#include "lldb/lldb-forward.h"        // for ValueObjectSP
+#include "lldb/Symbol/CompilerType.h"
+#include "lldb/lldb-defines.h"
+#include "lldb/lldb-enumerations.h"
+#include "lldb/lldb-forward.h"
 
-#include <stddef.h> // for size_t
-#include <stdint.h> // for uint32_t, uint64_t
+#include <stddef.h>
+#include <stdint.h>
 
 namespace lldb_private {
 class ConstString;
