@@ -10,13 +10,30 @@
 #ifndef liblldb_ValueObjectDynamicValue_h_
 #define liblldb_ValueObjectDynamicValue_h_
 
-// C Includes
-// C++ Includes
-// Other libraries and framework includes
-// Project includes
+#include "lldb/Core/Address.h"
 #include "lldb/Core/ValueObject.h"
+#include "lldb/Symbol/CompilerType.h"
 #include "lldb/Symbol/Type.h"
+#include "lldb/Utility/ConstString.h"
+#include "lldb/Utility/SharingPtr.h"
+#include "lldb/lldb-defines.h"
+#include "lldb/lldb-enumerations.h"
+#include "lldb/lldb-forward.h"
+#include "lldb/lldb-private-enumerations.h"
 
+#include <assert.h>
+#include <stddef.h>
+#include <stdint.h>
+
+namespace lldb_private {
+class DataExtractor;
+}
+namespace lldb_private {
+class Declaration;
+}
+namespace lldb_private {
+class Status;
+}
 namespace lldb_private {
 
 //----------------------------------------------------------------------
@@ -69,9 +86,9 @@ public:
     m_owning_valobj_sp = owning_sp;
   }
 
-  bool SetValueFromCString(const char *value_str, Error &error) override;
+  bool SetValueFromCString(const char *value_str, Status &error) override;
 
-  bool SetData(DataExtractor &data, Error &error) override;
+  bool SetData(DataExtractor &data, Status &error) override;
 
   TypeImpl GetTypeImpl() override;
 
