@@ -10,15 +10,16 @@
 #ifndef liblldb_ValueObjectList_h_
 #define liblldb_ValueObjectList_h_
 
-// C Includes
-// C++ Includes
+#include "lldb/lldb-forward.h"
+#include "lldb/lldb-types.h"
+
 #include <vector>
 
-// Other libraries and framework includes
-// Project includes
-#include "lldb/Core/UserID.h"
-#include "lldb/Target/ExecutionContextScope.h"
-#include "lldb/lldb-private.h"
+#include <stddef.h>
+
+namespace lldb_private {
+class ValueObject;
+}
 
 namespace lldb_private {
 
