@@ -10,16 +10,12 @@
 #ifndef liblldb_StringPrinter_h_
 #define liblldb_StringPrinter_h_
 
-// C Includes
-// C++ Includes
 #include <functional>
 #include <string>
 
-// Other libraries and framework includes
-// Project includes
 #include "lldb/lldb-forward.h"
 
-#include "lldb/Core/DataExtractor.h"
+#include "lldb/Utility/DataExtractor.h"
 
 namespace lldb_private {
 namespace formatters {
@@ -266,8 +262,7 @@ public:
   // I can't use a std::unique_ptr for this because the Deleter is a template
   // argument there
   // and I want the same type to represent both pointers I want to free and
-  // pointers I don't need
-  // to free - which is what this class essentially is
+  // pointers I don't need to free - which is what this class essentially is
   // It's very specialized to the needs of this file, and not suggested for
   // general use
   template <typename T = uint8_t, typename U = char, typename S = size_t>
