@@ -10,14 +10,11 @@
 #ifndef lldb_CommandCompletions_h_
 #define lldb_CommandCompletions_h_
 
-// C Includes
-// C++ Includes
 #include <set>
 
-// Other libraries and framework includes
-// Project includes
 #include "lldb/Core/FileSpecList.h"
 #include "lldb/Core/SearchFilter.h"
+#include "lldb/Utility/CompletionRequest.h"
 #include "lldb/Utility/RegularExpression.h"
 #include "lldb/lldb-private.h"
 
@@ -29,20 +26,13 @@ class CommandCompletions {
 public:
   //----------------------------------------------------------------------
   // This is the command completion callback that is used to complete the
-  // argument of the option
-  // it is bound to (in the OptionDefinition table below).  Return the total
-  // number of matches.
+  // argument of the option it is bound to (in the OptionDefinition table
+  // below).  Return the total number of matches.
   //----------------------------------------------------------------------
-  typedef int (*CompletionCallback)(
-      CommandInterpreter &interpreter,
-      llvm::StringRef completion_str, // This is the argument we are completing
-      int match_start_point,   // This is the point in the list of matches that
-                               // you should start returning elements
-      int max_return_elements, // This is the number of matches requested.
-      lldb_private::SearchFilter
-          *searcher, // A search filter to limit the search...
-      bool &word_complete,
-      lldb_private::StringList &matches); // The array of matches we return.
+  typedef int (*CompletionCallback)(CommandInterpreter &interpreter,
+                                    CompletionRequest &request,
+                                    // A search filter to limit the search...
+                                    lldb_private::SearchFilter *searcher);
   typedef enum {
     eNoCompletion = 0u,
     eSourceFileCompletion = (1u << 0),
@@ -54,9 +44,9 @@ public:
     ePlatformPluginCompletion = (1u << 6),
     eArchitectureCompletion = (1u << 7),
     eVariablePathCompletion = (1u << 8),
-    // This item serves two purposes.  It is the last element in the enum,
-    // so you can add custom enums starting from here in your Option class.
-    // Also if you & in this bit the base code will not process the option.
+    // This item serves two purposes.  It is the last element in the enum, so
+    // you can add custom enums starting from here in your Option class. Also
+    // if you & in this bit the base code will not process the option.
     eCustomCompletion = (1u << 9)
   } CommonCompletionTypes;
 
@@ -67,97 +57,68 @@ public:
 
   static bool InvokeCommonCompletionCallbacks(
       CommandInterpreter &interpreter, uint32_t completion_mask,
-      llvm::StringRef completion_str, int match_start_point,
-      int max_return_elements, SearchFilter *searcher, bool &word_complete,
-      StringList &matches);
+      lldb_private::CompletionRequest &request, SearchFilter *searcher);
 
   //----------------------------------------------------------------------
   // These are the generic completer functions:
   //----------------------------------------------------------------------
   static int DiskFiles(CommandInterpreter &interpreter,
-                       llvm::StringRef partial_file_name, int match_start_point,
-                       int max_return_elements, SearchFilter *searcher,
-                       bool &word_complete, StringList &matches);
+                       CompletionRequest &request, SearchFilter *searcher);
 
   static int DiskFiles(const llvm::Twine &partial_file_name,
                        StringList &matches, TildeExpressionResolver &Resolver);
 
   static int DiskDirectories(CommandInterpreter &interpreter,
-                             llvm::StringRef partial_file_name,
-                             int match_start_point, int max_return_elements,
-                             SearchFilter *searcher, bool &word_complete,
-                             StringList &matches);
+                             CompletionRequest &request,
+                             SearchFilter *searcher);
 
   static int DiskDirectories(const llvm::Twine &partial_file_name,
                              StringList &matches,
                              TildeExpressionResolver &Resolver);
 
   static int SourceFiles(CommandInterpreter &interpreter,
-                         llvm::StringRef partial_file_name,
-                         int match_start_point, int max_return_elements,
-                         SearchFilter *searcher, bool &word_complete,
-                         StringList &matches);
+                         CompletionRequest &request, SearchFilter *searcher);
 
   static int Modules(CommandInterpreter &interpreter,
-                     llvm::StringRef partial_file_name, int match_start_point,
-                     int max_return_elements, SearchFilter *searcher,
-                     bool &word_complete, lldb_private::StringList &matches);
+                     CompletionRequest &request, SearchFilter *searcher);
 
   static int Symbols(CommandInterpreter &interpreter,
-                     llvm::StringRef partial_file_name, int match_start_point,
-                     int max_return_elements, SearchFilter *searcher,
-                     bool &word_complete, lldb_private::StringList &matches);
+                     CompletionRequest &request, SearchFilter *searcher);
 
   static int SettingsNames(CommandInterpreter &interpreter,
-                           llvm::StringRef partial_file_name,
-                           int match_start_point, int max_return_elements,
-                           SearchFilter *searcher, bool &word_complete,
-                           lldb_private::StringList &matches);
+                           CompletionRequest &request, SearchFilter *searcher);
 
   static int PlatformPluginNames(CommandInterpreter &interpreter,
-                                 llvm::StringRef partial_file_name,
-                                 int match_start_point, int max_return_elements,
-                                 SearchFilter *searcher, bool &word_complete,
-                                 lldb_private::StringList &matches);
+                                 CompletionRequest &request,
+                                 SearchFilter *searcher);
 
   static int ArchitectureNames(CommandInterpreter &interpreter,
-                               llvm::StringRef partial_file_name,
-                               int match_start_point, int max_return_elements,
-                               SearchFilter *searcher, bool &word_complete,
-                               lldb_private::StringList &matches);
+                               CompletionRequest &request,
+                               SearchFilter *searcher);
 
   static int VariablePath(CommandInterpreter &interpreter,
-                          llvm::StringRef partial_file_name,
-                          int match_start_point, int max_return_elements,
-                          SearchFilter *searcher, bool &word_complete,
-                          lldb_private::StringList &matches);
+                          CompletionRequest &request, SearchFilter *searcher);
 
   //----------------------------------------------------------------------
-  // The Completer class is a convenient base class for building searchers
-  // that go along with the SearchFilter passed to the standard Completer
-  // functions.
+  // The Completer class is a convenient base class for building searchers that
+  // go along with the SearchFilter passed to the standard Completer functions.
   //----------------------------------------------------------------------
   class Completer : public Searcher {
   public:
-    Completer(CommandInterpreter &interpreter, llvm::StringRef completion_str,
-              int match_start_point, int max_return_elements,
-              StringList &matches);
+    Completer(CommandInterpreter &interpreter, CompletionRequest &request);
 
     ~Completer() override;
 
     CallbackReturn SearchCallback(SearchFilter &filter, SymbolContext &context,
                                   Address *addr, bool complete) override = 0;
 
-    Depth GetDepth() override = 0;
+    lldb::SearchDepth GetDepth() override = 0;
 
     virtual size_t DoCompletion(SearchFilter *filter) = 0;
 
   protected:
     CommandInterpreter &m_interpreter;
-    std::string m_completion_str;
-    int m_match_start_point;
-    int m_max_return_elements;
-    StringList &m_matches;
+    CompletionRequest &m_request;
 
   private:
     DISALLOW_COPY_AND_ASSIGN(Completer);
@@ -169,11 +130,9 @@ public:
   class SourceFileCompleter : public Completer {
   public:
     SourceFileCompleter(CommandInterpreter &interpreter,
-                        bool include_support_files,
-                        llvm::StringRef completion_str, int match_start_point,
-                        int max_return_elements, StringList &matches);
+                        bool include_support_files, CompletionRequest &request);
 
-    Searcher::Depth GetDepth() override;
+    lldb::SearchDepth GetDepth() override;
 
     Searcher::CallbackReturn SearchCallback(SearchFilter &filter,
                                             SymbolContext &context,
@@ -197,10 +156,9 @@ public:
   class ModuleCompleter : public Completer {
   public:
     ModuleCompleter(CommandInterpreter &interpreter,
-                    llvm::StringRef completion_str, int match_start_point,
-                    int max_return_elements, StringList &matches);
+                    CompletionRequest &request);
 
-    Searcher::Depth GetDepth() override;
+    lldb::SearchDepth GetDepth() override;
 
     Searcher::CallbackReturn SearchCallback(SearchFilter &filter,
                                             SymbolContext &context,
@@ -222,10 +180,9 @@ public:
   class SymbolCompleter : public Completer {
   public:
     SymbolCompleter(CommandInterpreter &interpreter,
-                    llvm::StringRef completion_str, int match_start_point,
-                    int max_return_elements, StringList &matches);
+                    CompletionRequest &request);
 
-    Searcher::Depth GetDepth() override;
+    lldb::SearchDepth GetDepth() override;
 
     Searcher::CallbackReturn SearchCallback(SearchFilter &filter,
                                             SymbolContext &context,
