@@ -10,40 +10,37 @@
 #ifndef liblldb_Block_h_
 #define liblldb_Block_h_
 
-// C Includes
-// C++ Includes
 #include <vector>
 
-// Other libraries and framework includes
-// Project includes
 #include "lldb/Core/AddressRange.h"
 #include "lldb/Core/RangeMap.h"
-#include "lldb/Core/Stream.h"
-#include "lldb/Core/UserID.h"
 #include "lldb/Symbol/CompilerType.h"
 #include "lldb/Symbol/LineEntry.h"
 #include "lldb/Symbol/SymbolContext.h"
+#include "lldb/Symbol/SymbolContextScope.h"
+#include "lldb/Utility/Stream.h"
+#include "lldb/Utility/UserID.h"
 #include "lldb/lldb-private.h"
 
 namespace lldb_private {
 
 //----------------------------------------------------------------------
 /// @class Block Block.h "lldb/Symbol/Block.h"
-/// @brief A class that describes a single lexical block.
+/// A class that describes a single lexical block.
 ///
 /// A Function object owns a BlockList object which owns one or more
-/// Block objects. The BlockList object contains a section offset
-/// address range, and Block objects contain one or more ranges
-/// which are offsets into that range. Blocks are can have discontiguous
-/// ranges within the BlockList address range, and each block can
-/// contain child blocks each with their own sets of ranges.
+/// Block objects. The BlockList object contains a section offset address
+/// range, and Block objects contain one or more ranges which are offsets into
+/// that range. Blocks are can have discontiguous ranges within the BlockList
+/// address range, and each block can contain child blocks each with their own
+/// sets of ranges.
 ///
-/// Each block has a variable list that represents local, argument, and
-/// static variables that are scoped to the block.
+/// Each block has a variable list that represents local, argument, and static
+/// variables that are scoped to the block.
 ///
-/// Inlined functions are represented by attaching a
-/// InlineFunctionInfo shared pointer object to a block. Inlined
-/// functions are represented as named blocks.
+/// Inlined functions are represented by attaching a InlineFunctionInfo shared
+/// pointer object to a block. Inlined functions are represented as named
+/// blocks.
 //----------------------------------------------------------------------
 class Block : public UserID, public SymbolContextScope {
 public:
@@ -53,10 +50,9 @@ public:
   //------------------------------------------------------------------
   /// Construct with a User ID \a uid, \a depth.
   ///
-  /// Initialize this block with the specified UID \a uid. The
-  /// \a depth in the \a block_list is used to represent the parent,
-  /// sibling, and child block information and also allows for partial
-  /// parsing at the block level.
+  /// Initialize this block with the specified UID \a uid. The \a depth in the
+  /// \a block_list is used to represent the parent, sibling, and child block
+  /// information and also allows for partial parsing at the block level.
   ///
   /// @param[in] uid
   ///     The UID for a given block. This value is given by the
@@ -145,8 +141,7 @@ public:
   bool Contains(const Range &range) const;
 
   //------------------------------------------------------------------
-  /// Check if this object contains "block" as a child block at any
-  /// depth.
+  /// Check if this object contains "block" as a child block at any depth.
   ///
   /// @param[in] block
   ///     A potential child block.
@@ -255,8 +250,8 @@ public:
   lldb::VariableListSP GetBlockVariableList(bool can_create);
 
   //------------------------------------------------------------------
-  /// Get the variable list for this block and optionally all child
-  /// blocks if \a get_child_variables is \b true.
+  /// Get the variable list for this block and optionally all child blocks if
+  /// \a get_child_variables is \b true.
   ///
   /// @param[in] get_child_variables
   ///     If \b true, all variables from all child blocks will be
@@ -285,8 +280,8 @@ public:
                                 VariableList *variable_list);
 
   //------------------------------------------------------------------
-  /// Appends the variables from this block, and optionally from all
-  /// parent blocks, to \a variable_list.
+  /// Appends the variables from this block, and optionally from all parent
+  /// blocks, to \a variable_list.
   ///
   /// @param[in] can_create
   ///     If \b true, the variables can be parsed if they already
@@ -328,13 +323,21 @@ public:
     return m_inlineInfoSP.get();
   }
 
+  //------------------------------------------------------------------
+  /// Get the symbol file which contains debug info for this block's
+  /// symbol context module.
+  ///
+  /// @return A pointer to the symbol file or nullptr.
+  //------------------------------------------------------------------
+  SymbolFile *GetSymbolFile();
+
   CompilerDeclContext GetDeclContext();
 
   //------------------------------------------------------------------
   /// Get the memory cost of this object.
   ///
-  /// Returns the cost of this object plus any owned objects from the
-  /// ranges, variables, and inline function information.
+  /// Returns the cost of this object plus any owned objects from the ranges,
+  /// variables, and inline function information.
   ///
   /// @return
   ///     The number of bytes that this object occupies in memory.
@@ -373,9 +376,8 @@ public:
   //------------------------------------------------------------------
   /// Set accessor for the variable list.
   ///
-  /// Called by the SymbolFile plug-ins after they have parsed the
-  /// variable lists and are ready to hand ownership of the list over
-  /// to this object.
+  /// Called by the SymbolFile plug-ins after they have parsed the variable
+  /// lists and are ready to hand ownership of the list over to this object.
   ///
   /// @param[in] variable_list_sp
   ///     A shared pointer to a VariableList.
@@ -402,8 +404,8 @@ public:
   uint32_t GetRangeIndexContainingAddress(const Address &addr);
 
   //------------------------------------------------------------------
-  // Since blocks might have multiple discontiguous address ranges,
-  // we need to be able to get at any of the address ranges in a block.
+  // Since blocks might have multiple discontiguous address ranges, we need to
+  // be able to get at any of the address ranges in a block.
   //------------------------------------------------------------------
   bool GetRangeAtIndex(uint32_t range_idx, AddressRange &range);
 
