@@ -16,15 +16,16 @@
 #include "lldb/Symbol/Block.h"
 #include "lldb/Symbol/Declaration.h"
 #include "lldb/Utility/UserID.h"
+#include "llvm/ADT/ArrayRef.h"
 
 namespace lldb_private {
 
 //----------------------------------------------------------------------
 /// @class FunctionInfo Function.h "lldb/Symbol/Function.h"
-/// @brief A class that contains generic function information.
+/// A class that contains generic function information.
 ///
-/// This provides generic function information that gets reused between
-/// inline functions and function types.
+/// This provides generic function information that gets reused between inline
+/// functions and function types.
 //----------------------------------------------------------------------
 class FunctionInfo {
 public:
@@ -67,8 +68,8 @@ public:
   //------------------------------------------------------------------
   /// Compare two function information objects.
   ///
-  /// First compares the method names, and if equal, then compares
-  /// the declaration information.
+  /// First compares the method names, and if equal, then compares the
+  /// declaration information.
   ///
   /// @param[in] lhs
   ///     The Left Hand Side const FunctionInfo object reference.
@@ -86,8 +87,8 @@ public:
   //------------------------------------------------------------------
   /// Dump a description of this object to a Stream.
   ///
-  /// Dump a description of the contents of this object to the
-  /// supplied stream \a s.
+  /// Dump a description of the contents of this object to the supplied stream
+  /// \a s.
   ///
   /// @param[in] s
   ///     The stream to which to dump the object description.
@@ -141,13 +142,13 @@ protected:
 
 //----------------------------------------------------------------------
 /// @class InlineFunctionInfo Function.h "lldb/Symbol/Function.h"
-/// @brief A class that describes information for an inlined function.
+/// A class that describes information for an inlined function.
 //----------------------------------------------------------------------
 class InlineFunctionInfo : public FunctionInfo {
 public:
   //------------------------------------------------------------------
-  /// Construct with the function method name, mangled name, and
-  /// optional declaration information.
+  /// Construct with the function method name, mangled name, and optional
+  /// declaration information.
   ///
   /// @param[in] name
   ///     A C string name for the method name for this function. This
@@ -171,8 +172,8 @@ public:
                      const Declaration *call_decl_ptr);
 
   //------------------------------------------------------------------
-  /// Construct with the function method name, mangled name, and
-  /// optional declaration information.
+  /// Construct with the function method name, mangled name, and optional
+  /// declaration information.
   ///
   /// @param[in] name
   ///     A name for the method name for this function. This value
@@ -202,8 +203,8 @@ public:
   //------------------------------------------------------------------
   /// Compare two inlined function information objects.
   ///
-  /// First compares the FunctionInfo objects, and if equal,
-  /// compares the mangled names.
+  /// First compares the FunctionInfo objects, and if equal, compares the
+  /// mangled names.
   ///
   /// @param[in] lhs
   ///     The Left Hand Side const InlineFunctionInfo object
@@ -223,8 +224,8 @@ public:
   //------------------------------------------------------------------
   /// Dump a description of this object to a Stream.
   ///
-  /// Dump a description of the contents of this object to the
-  /// supplied stream \a s.
+  /// Dump a description of the contents of this object to the supplied stream
+  /// \a s.
   ///
   /// @param[in] s
   ///     The stream to which to dump the object description.
@@ -290,19 +291,75 @@ private:
   Declaration m_call_decl;
 };
 
+class Function;
+
+//----------------------------------------------------------------------
+/// @class CallEdge Function.h "lldb/Symbol/Function.h"
+///
+/// Represent a call made within a Function. This can be used to find a path
+/// in the call graph between two functions.
+//----------------------------------------------------------------------
+class CallEdge {
+public:
+  /// Construct a call edge using a symbol name to identify the calling
+  /// function, and a return PC within the calling function to identify a
+  /// specific call site.
+  ///
+  /// TODO: A symbol name may not be globally unique. To disambiguate ODR
+  /// conflicts, it's necessary to determine the \c Target a call edge is
+  /// associated with before resolving it.
+  CallEdge(const char *symbol_name, lldb::addr_t return_pc);
+
+  CallEdge(CallEdge &&) = default;
+  CallEdge &operator=(CallEdge &&) = default;
+
+  /// Get the callee's definition.
+  ///
+  /// Note that this might lazily invoke the DWARF parser.
+  Function *GetCallee(ModuleList &images);
+
+  /// Get the load PC address of the instruction which executes after the call
+  /// returns. Returns LLDB_INVALID_ADDRESS iff this is a tail call. \p caller
+  /// is the Function containing this call, and \p target is the Target which
+  /// made the call.
+  lldb::addr_t GetReturnPCAddress(Function &caller, Target &target) const;
+
+  /// Like \ref GetReturnPCAddress, but returns an unslid function-local PC
+  /// offset.
+  lldb::addr_t GetUnresolvedReturnPCAddress() const { return return_pc; }
+
+private:
+  void ParseSymbolFileAndResolve(ModuleList &images);
+
+  /// Either the callee's mangled name or its definition, discriminated by
+  /// \ref resolved.
+  union {
+    const char *symbol_name;
+    Function *def;
+  } lazy_callee;
+
+  /// An invalid address if this is a tail call. Otherwise, the function-local
+  /// PC offset. Adding this PC offset to the function's base load address
+  /// gives the return PC for the call.
+  lldb::addr_t return_pc;
+
+  /// Whether or not an attempt was made to find the callee's definition.
+  bool resolved;
+
+  DISALLOW_COPY_AND_ASSIGN(CallEdge);
+};
+
 //----------------------------------------------------------------------
 /// @class Function Function.h "lldb/Symbol/Function.h"
-/// @brief A class that describes a function.
+/// A class that describes a function.
 ///
-/// Functions belong to CompileUnit objects (Function::m_comp_unit),
-/// have unique user IDs (Function::UserID), know how to reconstruct
-/// their symbol context (Function::SymbolContextScope), have a
-/// specific function type (Function::m_type_uid), have a simple
-/// method name (FunctionInfo::m_name), be declared at a specific
-/// location (FunctionInfo::m_declaration), possibly have mangled
-/// names (Function::m_mangled), an optional return type
-/// (Function::m_type), and contains lexical blocks
-/// (Function::m_blocks).
+/// Functions belong to CompileUnit objects (Function::m_comp_unit), have
+/// unique user IDs (Function::UserID), know how to reconstruct their symbol
+/// context (Function::SymbolContextScope), have a specific function type
+/// (Function::m_type_uid), have a simple method name (FunctionInfo::m_name),
+/// be declared at a specific location (FunctionInfo::m_declaration), possibly
+/// have mangled names (Function::m_mangled), an optional return type
+/// (Function::m_type), and contains lexical blocks (Function::m_blocks).
 ///
 /// The function information is split into a few pieces:
 ///     @li The concrete instance information
@@ -311,15 +368,14 @@ private:
 /// The abstract information is found in the function type (Type) that
 /// describes a function information, return type and parameter types.
 ///
-/// The concrete information is the address range information and
-/// specific locations for an instance of this function.
+/// The concrete information is the address range information and specific
+/// locations for an instance of this function.
 //----------------------------------------------------------------------
 class Function : public UserID, public SymbolContextScope {
 public:
   //------------------------------------------------------------------
-  /// Construct with a compile unit, function UID, function type UID,
-  /// optional mangled name, function type, and a section offset
-  /// based address range.
+  /// Construct with a compile unit, function UID, function type UID, optional
+  /// mangled name, function type, and a section offset based address range.
   ///
   /// @param[in] comp_unit
   ///     The compile unit to which this function belongs.
@@ -351,41 +407,6 @@ public:
            lldb::user_id_t func_type_uid, const Mangled &mangled,
            Type *func_type, const AddressRange &range);
 
-  //------------------------------------------------------------------
-  /// Construct with a compile unit, function UID, function type UID,
-  /// optional mangled name, function type, and a section offset
-  /// based address range.
-  ///
-  /// @param[in] comp_unit
-  ///     The compile unit to which this function belongs.
-  ///
-  /// @param[in] func_uid
-  ///     The UID for this function. This value is provided by the
-  ///     SymbolFile plug-in and can be any value that allows
-  ///     the plug-in to quickly find and parse more detailed
-  ///     information when and if more information is needed.
-  ///
-  /// @param[in] func_type_uid
-  ///     The type UID for the function Type to allow for lazy type
-  ///     parsing from the debug information.
-  ///
-  /// @param[in] mangled
-  ///     The optional mangled name for this function. If empty, there
-  ///     is no mangled information.
-  ///
-  /// @param[in] func_type
-  ///     The optional function type. If NULL, the function type will
-  ///     be parsed on demand when accessed using the
-  ///     Function::GetType() function by asking the SymbolFile
-  ///     plug-in to get the type for \a func_type_uid.
-  ///
-  /// @param[in] range
-  ///     The section offset based address for this function.
-  //------------------------------------------------------------------
-  Function(CompileUnit *comp_unit, lldb::user_id_t func_uid,
-           lldb::user_id_t func_type_uid, const char *mangled, Type *func_type,
-           const AddressRange &range);
-
   //------------------------------------------------------------------
   /// Destructor.
   //------------------------------------------------------------------
@@ -408,10 +429,10 @@ public:
 
   lldb::LanguageType GetLanguage() const;
   //------------------------------------------------------------------
-  /// Find the file and line number of the source location of the start
-  /// of the function.  This will use the declaration if present and fall
-  /// back on the line table if that fails.  So there may NOT be a line
-  /// table entry for this source file/line combo.
+  /// Find the file and line number of the source location of the start of the
+  /// function.  This will use the declaration if present and fall back on the
+  /// line table if that fails.  So there may NOT be a line table entry for
+  /// this source file/line combo.
   ///
   /// @param[out] source_file
   ///     The source file.
@@ -422,8 +443,8 @@ public:
   void GetStartLineSourceInfo(FileSpec &source_file, uint32_t &line_no);
 
   //------------------------------------------------------------------
-  /// Find the file and line number of the source location of the end
-  /// of the function.
+  /// Find the file and line number of the source location of the end of the
+  /// function.
   ///
   ///
   /// @param[out] source_file
@@ -434,6 +455,18 @@ public:
   //------------------------------------------------------------------
   void GetEndLineSourceInfo(FileSpec &source_file, uint32_t &line_no);
 
+  //------------------------------------------------------------------
+  /// Get the outgoing call edges from this function, sorted by their return
+  /// PC addresses (in increasing order).
+  //------------------------------------------------------------------
+  llvm::MutableArrayRef<CallEdge> GetCallEdges();
+
+  //------------------------------------------------------------------
+  /// Get the outgoing tail-calling edges from this function. If none exist,
+  /// return None.
+  //------------------------------------------------------------------
+  llvm::MutableArrayRef<CallEdge> GetTailCallingEdges();
+
   //------------------------------------------------------------------
   /// Get accessor for the block list.
   ///
@@ -497,8 +530,8 @@ public:
   CompilerDeclContext GetDeclContext();
 
   //------------------------------------------------------------------
-  /// Get accessor for the type that describes the function
-  /// return value type, and parameter types.
+  /// Get accessor for the type that describes the function return value type,
+  /// and parameter types.
   ///
   /// @return
   ///     A type object pointer.
@@ -506,8 +539,8 @@ public:
   Type *GetType();
 
   //------------------------------------------------------------------
-  /// Get const accessor for the type that describes the function
-  /// return value type, and parameter types.
+  /// Get const accessor for the type that describes the function return value
+  /// type, and parameter types.
   ///
   /// @return
   ///     A const type object pointer.
@@ -518,10 +551,8 @@ public:
 
   //------------------------------------------------------------------
   /// Get the size of the prologue instructions for this function.  The
-  /// "prologue"
-  /// instructions include any instructions given line number 0 immediately
-  /// following
-  /// the prologue end.
+  /// "prologue" instructions include any instructions given line number 0
+  /// immediately following the prologue end.
   ///
   /// @return
   ///     The size of the prologue.
@@ -531,8 +562,8 @@ public:
   //------------------------------------------------------------------
   /// Dump a description of this object to a Stream.
   ///
-  /// Dump a description of the contents of this object to the
-  /// supplied stream \a s.
+  /// Dump a description of the contents of this object to the supplied stream
+  /// \a s.
   ///
   /// @param[in] s
   ///     The stream to which to dump the object description.
@@ -567,10 +598,10 @@ public:
   ///
   /// The debug information may provide information about whether this
   /// function was compiled with optimization or not.  In this case,
-  /// "optimized" means that the debug experience may be difficult
-  /// for the user to understand.  Variables may not be available when
-  /// the developer would expect them, stepping through the source lines
-  /// in the function may appear strange, etc.
+  /// "optimized" means that the debug experience may be difficult for the
+  /// user to understand.  Variables may not be available when the developer
+  /// would expect them, stepping through the source lines in the function may
+  /// appear strange, etc.
   ///
   /// @return
   ///     Returns 'true' if this function was compiled with
@@ -582,10 +613,10 @@ public:
   //------------------------------------------------------------------
   /// Get whether this function represents a 'top-level' function
   ///
-  /// The concept of a top-level function is language-specific, mostly
-  /// meant to represent the notion of scripting-style code that has
-  /// global visibility of the variables/symbols/functions/...
-  /// defined within the containing file/module
+  /// The concept of a top-level function is language-specific, mostly meant
+  /// to represent the notion of scripting-style code that has global
+  /// visibility of the variables/symbols/functions/... defined within the
+  /// containing file/module
   ///
   /// If stopped in a top-level function, LLDB will expose global variables
   /// as-if locals in the 'frame variable' command
@@ -627,6 +658,10 @@ protected:
   Flags m_flags;
   uint32_t
       m_prologue_byte_size; ///< Compute the prologue size once and cache it
+
+  bool m_call_edges_resolved = false; ///< Whether call site info has been
+                                      ///  parsed.
+  std::vector<CallEdge> m_call_edges; ///< Outgoing call edges.
 private:
   DISALLOW_COPY_AND_ASSIGN(Function);
 };
