@@ -10,15 +10,11 @@
 #ifndef liblldb_Memory_h_
 #define liblldb_Memory_h_
 
-// C Includes
-// C++ Includes
 #include <map>
 #include <mutex>
 #include <vector>
 
-// Other libraries and framework includes
 
-// Project includes
 #include "lldb/Core/RangeMap.h"
 #include "lldb/lldb-private.h"
 
@@ -40,7 +36,7 @@ public:
 
   void Flush(lldb::addr_t addr, size_t size);
 
-  size_t Read(lldb::addr_t addr, void *dst, size_t dst_len, Error &error);
+  size_t Read(lldb::addr_t addr, void *dst, size_t dst_len, Status &error);
 
   uint32_t GetMemoryCacheLineSize() const { return m_L2_cache_line_byte_size; }
 
@@ -75,6 +71,8 @@ private:
   DISALLOW_COPY_AND_ASSIGN(MemoryCache);
 };
 
+    
+
 class AllocatedBlock {
 public:
   AllocatedBlock(lldb::addr_t addr, uint32_t byte_size, uint32_t permissions,
@@ -86,38 +84,40 @@ public:
 
   bool FreeBlock(lldb::addr_t addr);
 
-  lldb::addr_t GetBaseAddress() const { return m_addr; }
+  lldb::addr_t GetBaseAddress() const { return m_range.GetRangeBase(); }
 
-  uint32_t GetByteSize() const { return m_byte_size; }
+  uint32_t GetByteSize() const { return m_range.GetByteSize(); }
 
   uint32_t GetPermissions() const { return m_permissions; }
 
   uint32_t GetChunkSize() const { return m_chunk_size; }
 
   bool Contains(lldb::addr_t addr) const {
-    return ((addr >= m_addr) && addr < (m_addr + m_byte_size));
+    return m_range.Contains(addr);
   }
 
 protected:
-  uint32_t TotalChunks() const { return m_byte_size / m_chunk_size; }
+  uint32_t TotalChunks() const { return GetByteSize() / GetChunkSize(); }
 
   uint32_t CalculateChunksNeededForSize(uint32_t size) const {
     return (size + m_chunk_size - 1) / m_chunk_size;
   }
-  const lldb::addr_t m_addr;    // Base address of this block of memory
-  const uint32_t m_byte_size;   // 4GB of chunk should be enough...
-  const uint32_t m_permissions; // Permissions for this memory (logical OR of
-                                // lldb::Permissions bits)
-  const uint32_t m_chunk_size;  // The size of chunks that the memory at m_addr
-                                // is divied up into
-  typedef std::map<uint32_t, uint32_t> OffsetToChunkSize;
-  OffsetToChunkSize m_offset_to_chunk_size;
+  // Base address of this block of memory 4GB of chunk should be enough.
+  Range<lldb::addr_t, uint32_t> m_range;
+  // Permissions for this memory (logical OR of lldb::Permissions bits)
+  const uint32_t m_permissions;
+  // The size of chunks that the memory at m_addr is divied up into.
+  const uint32_t m_chunk_size;
+  // A sorted list of free address ranges.
+  RangeVector<lldb::addr_t, uint32_t> m_free_blocks;
+  // A sorted list of reserved address.
+  RangeVector<lldb::addr_t, uint32_t> m_reserved_blocks;
 };
 
 //----------------------------------------------------------------------
 // A class that can track allocated memory and give out allocated memory
-// without us having to make an allocate/deallocate call every time we
-// need some memory in a process that is being debugged.
+// without us having to make an allocate/deallocate call every time we need
+// some memory in a process that is being debugged.
 //----------------------------------------------------------------------
 class AllocatedMemoryCache {
 public:
@@ -131,7 +131,7 @@ public:
   void Clear();
 
   lldb::addr_t AllocateMemory(size_t byte_size, uint32_t permissions,
-                              Error &error);
+                              Status &error);
 
   bool DeallocateMemory(lldb::addr_t ptr);
 
@@ -139,7 +139,7 @@ protected:
   typedef std::shared_ptr<AllocatedBlock> AllocatedBlockSP;
 
   AllocatedBlockSP AllocatePage(uint32_t byte_size, uint32_t permissions,
-                                uint32_t chunk_size, Error &error);
+                                uint32_t chunk_size, Status &error);
 
   //------------------------------------------------------------------
   // Classes that inherit from MemoryCache can see and modify these
