@@ -11,10 +11,10 @@
 #define LLDB_CORE_DATABUFFERLLVM_H
 
 #include "lldb/Utility/DataBuffer.h"
-#include "lldb/lldb-types.h" // for offset_t
+#include "lldb/lldb-types.h"
 
 #include <memory>
-#include <stdint.h> // for uint8_t, uint64_t
+#include <stdint.h>
 
 namespace llvm {
 class WritableMemoryBuffer;
@@ -23,16 +23,11 @@ class Twine;
 
 namespace lldb_private {
 
+class FileSystem;
 class DataBufferLLVM : public DataBuffer {
 public:
   ~DataBufferLLVM();
 
-  static std::shared_ptr<DataBufferLLVM>
-  CreateSliceFromPath(const llvm::Twine &Path, uint64_t Size, uint64_t Offset);
-
-  static std::shared_ptr<DataBufferLLVM>
-  CreateFromPath(const llvm::Twine &Path);
-
   uint8_t *GetBytes() override;
   const uint8_t *GetBytes() const override;
   lldb::offset_t GetByteSize() const override;
@@ -40,6 +35,7 @@ public:
   char *GetChars() { return reinterpret_cast<char *>(GetBytes()); }
 
 private:
+  friend FileSystem;
   /// Construct a DataBufferLLVM from \p Buffer.  \p Buffer must be a valid
   /// pointer.
   explicit DataBufferLLVM(std::unique_ptr<llvm::WritableMemoryBuffer> Buffer);
