@@ -21,7 +21,7 @@ class AttachResumeTestCase(TestBase):
 
     @skipIfRemote
     @expectedFailureAll(oslist=['freebsd'], bugnumber='llvm.org/pr19310')
-    @expectedFailureAll(oslist=["windows"], bugnumber="llvm.org/pr24778")
+    @skipIfWindows # llvm.org/pr24778, llvm.org/pr21753
     def test_attach_continue_interrupt_detach(self):
         """Test attach/continue/interrupt/detach"""
         self.build()
@@ -30,7 +30,7 @@ class AttachResumeTestCase(TestBase):
     def process_attach_continue_interrupt_detach(self):
         """Test attach/continue/interrupt/detach"""
 
-        exe = os.path.join(os.getcwd(), exe_name)
+        exe = self.getBuildArtifact(exe_name)
 
         popen = self.spawnSubprocess(exe)
         self.addTearDownHook(self.cleanupSubprocesses)
