@@ -15,13 +15,10 @@ from lldbsuite.test import lldbutil
 class StdTupleDataFormatterTestCase(TestBase):
     mydir = TestBase.compute_mydir(__file__)
 
-    @skipIfFreeBSD
-    @skipIfWindows  # libstdcpp not ported to Windows
-    @skipIfDarwin  # doesn't compile on Darwin
-    @skipIfwatchOS  # libstdcpp not ported to watchos
+    @add_test_categories(["libstdcxx"])
     def test_with_run_command(self):
         self.build()
-        self.runCmd("file a.out", CURRENT_EXECUTABLE_SET)
+        self.runCmd("file " + self.getBuildArtifact("a.out"), CURRENT_EXECUTABLE_SET)
 
         lldbutil.run_break_set_by_source_regexp(
             self, "Set break point at this line.")
@@ -43,7 +40,7 @@ class StdTupleDataFormatterTestCase(TestBase):
 
         self.assertEqual('"foobar"', frame.GetValueForVariablePath("ts[0]").GetSummary())
         self.assertFalse(frame.GetValueForVariablePath("ts[1]").IsValid())
-        
+
         self.assertEqual(1, frame.GetValueForVariablePath("tt[0]").GetValueAsUnsigned())
         self.assertEqual('"baz"', frame.GetValueForVariablePath("tt[1]").GetSummary())
         self.assertEqual(2, frame.GetValueForVariablePath("tt[2]").GetValueAsUnsigned())
