@@ -32,7 +32,7 @@ class PrintObjectArrayTestCase(TestBase):
 
     def printarray_data_formatter_commands(self):
         """Test that expr -O -Z works"""
-        self.runCmd("file a.out", CURRENT_EXECUTABLE_SET)
+        self.runCmd("file " + self.getBuildArtifact("a.out"), CURRENT_EXECUTABLE_SET)
 
         lldbutil.run_break_set_by_file_and_line(
             self, "main.mm", self.line, num_expected_locations=1, loc_exact=True)
