@@ -20,6 +20,7 @@ class TestInlineStepping(TestBase):
     @expectedFailureAll(
         compiler="icc",
         bugnumber="# Not really a bug.  ICC combines two inlined functions.")
+    @expectedFailureAll(oslist=["windows"], bugnumber="llvm.org/pr32343")
     def test_with_python_api(self):
         """Test stepping over and into inlined functions."""
         self.build()
@@ -32,6 +33,7 @@ class TestInlineStepping(TestBase):
         self.inline_stepping_step_over()
 
     @add_test_categories(['pyapi'])
+    @expectedFailureAll(oslist=["windows"], bugnumber="llvm.org/pr32343")
     def test_step_in_template_with_python_api(self):
         """Test stepping in to templated functions."""
         self.build()
@@ -145,7 +147,7 @@ class TestInlineStepping(TestBase):
 
     def inline_stepping(self):
         """Use Python APIs to test stepping over and hitting breakpoints."""
-        exe = os.path.join(os.getcwd(), "a.out")
+        exe = self.getBuildArtifact("a.out")
 
         target = self.dbg.CreateTarget(exe)
         self.assertTrue(target, VALID_TARGET)
@@ -257,7 +259,7 @@ class TestInlineStepping(TestBase):
 
     def inline_stepping_step_over(self):
         """Use Python APIs to test stepping over and hitting breakpoints."""
-        exe = os.path.join(os.getcwd(), "a.out")
+        exe = self.getBuildArtifact("a.out")
 
         target = self.dbg.CreateTarget(exe)
         self.assertTrue(target, VALID_TARGET)
@@ -288,7 +290,7 @@ class TestInlineStepping(TestBase):
 
     def step_in_template(self):
         """Use Python APIs to test stepping in to templated functions."""
-        exe = os.path.join(os.getcwd(), "a.out")
+        exe = self.getBuildArtifact("a.out")
 
         target = self.dbg.CreateTarget(exe)
         self.assertTrue(target, VALID_TARGET)
