@@ -64,7 +64,7 @@ class NumberOfThreadsTestCase(TestBase):
             'Number of expected threads and actual threads do not match.')
 
     @skipIfDarwin # rdar://33462362
-    @expectedFailureAll(oslist=["windows"], bugnumber="llvm.org/pr37658")
+    @skipIfWindows # This is flakey on Windows: llvm.org/pr37658, llvm.org/pr38373
     def test_unique_stacks(self):
         """Test backtrace unique with multiple threads executing the same stack."""
         self.build()
