@@ -33,7 +33,7 @@ class TsanBasicTestCase(TestBase):
         self.line_thread2 = line_number('main.c', '// thread2 line')
 
     def tsan_tests(self):
-        exe = os.path.join(os.getcwd(), "a.out")
+        exe = self.getBuildArtifact("a.out")
         self.expect(
             "file " + exe,
             patterns=["Current executable set to .*a.out"])
