@@ -30,7 +30,7 @@ class TsanGlobalLocationTestCase(TestBase):
         TestBase.setUp(self)
 
     def tsan_tests(self):
-        exe = os.path.join(os.getcwd(), "a.out")
+        exe = self.getBuildArtifact("a.out")
         self.expect(
             "file " + exe,
             patterns=["Current executable set to .*a.out"])
