@@ -32,7 +32,7 @@ class ConstStringTestCase(TestBase):
         self.build(dictionary=self.d)
         self.setTearDownCleanup(self.d)
 
-        exe = os.path.join(os.getcwd(), "a.out")
+        exe = self.getBuildArtifact("a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
         lldbutil.run_break_set_by_file_and_line(
