@@ -28,7 +28,7 @@ class TestObjCSuperMethod(TestBase):
     def test_with_python_api(self):
         """Test calling methods on super."""
         self.build()
-        exe = os.path.join(os.getcwd(), "a.out")
+        exe = self.getBuildArtifact("a.out")
 
         target = self.dbg.CreateTarget(exe)
         self.assertTrue(target, VALID_TARGET)
