@@ -30,7 +30,7 @@ class BuiltinTrapTestCase(TestBase):
     def test_with_run_command(self):
         """Test that LLDB handles a function with __builtin_trap correctly."""
         self.build()
-        self.runCmd("file a.out", CURRENT_EXECUTABLE_SET)
+        self.runCmd("file " + self.getBuildArtifact("a.out"), CURRENT_EXECUTABLE_SET)
 
         lldbutil.run_break_set_by_file_and_line(self, "main.cpp", self.line,
                                                 num_expected_locations=1,
