@@ -47,20 +47,20 @@ SBType::SBType(const SBType &rhs) : m_opaque_sp() {
 //{}
 //
 bool SBType::operator==(SBType &rhs) {
-  if (IsValid() == false)
+  if (!IsValid())
     return !rhs.IsValid();
 
-  if (rhs.IsValid() == false)
+  if (!rhs.IsValid())
     return false;
 
   return *m_opaque_sp.get() == *rhs.m_opaque_sp.get();
 }
 
 bool SBType::operator!=(SBType &rhs) {
-  if (IsValid() == false)
+  if (!IsValid())
     return rhs.IsValid();
 
-  if (rhs.IsValid() == false)
+  if (!rhs.IsValid())
     return true;
 
   return *m_opaque_sp.get() != *rhs.m_opaque_sp.get();
@@ -103,10 +103,11 @@ bool SBType::IsValid() const {
 }
 
 uint64_t SBType::GetByteSize() {
-  if (!IsValid())
-    return 0;
-
-  return m_opaque_sp->GetCompilerType(false).GetByteSize(nullptr);
+  if (IsValid())
+    if (llvm::Optional<uint64_t> size =
+            m_opaque_sp->GetCompilerType(false).GetByteSize(nullptr))
+      return *size;
+  return 0;
 }
 
 bool SBType::IsPointerType() {
@@ -451,7 +452,7 @@ SBTypeList::SBTypeList(const SBTypeList &rhs)
     Append(const_cast<SBTypeList &>(rhs).GetTypeAtIndex(i));
 }
 
-bool SBTypeList::IsValid() { return (m_opaque_ap.get() != NULL); }
+bool SBTypeList::IsValid() { return (m_opaque_ap != NULL); }
 
 SBTypeList &SBTypeList::operator=(const SBTypeList &rhs) {
   if (this != &rhs) {
@@ -469,7 +470,7 @@ void SBTypeList::Append(SBType type) {
 }
 
 SBType SBTypeList::GetTypeAtIndex(uint32_t index) {
-  if (m_opaque_ap.get())
+  if (m_opaque_ap)
     return SBType(m_opaque_ap->GetTypeAtIndex(index));
   return SBType();
 }
@@ -500,39 +501,39 @@ lldb::SBTypeMember &SBTypeMember::operator=(const lldb::SBTypeMember &rhs) {
 bool SBTypeMember::IsValid() const { return m_opaque_ap.get(); }
 
 const char *SBTypeMember::GetName() {
-  if (m_opaque_ap.get())
+  if (m_opaque_ap)
     return m_opaque_ap->GetName().GetCString();
   return NULL;
 }
 
 SBType SBTypeMember::GetType() {
   SBType sb_type;
-  if (m_opaque_ap.get()) {
+  if (m_opaque_ap) {
     sb_type.SetSP(m_opaque_ap->GetTypeImpl());
   }
   return sb_type;
 }
 
 uint64_t SBTypeMember::GetOffsetInBytes() {
-  if (m_opaque_ap.get())
+  if (m_opaque_ap)
     return m_opaque_ap->GetBitOffset() / 8u;
   return 0;
 }
 
 uint64_t SBTypeMember::GetOffsetInBits() {
-  if (m_opaque_ap.get())
+  if (m_opaque_ap)
     return m_opaque_ap->GetBitOffset();
   return 0;
 }
 
 bool SBTypeMember::IsBitfield() {
-  if (m_opaque_ap.get())
+  if (m_opaque_ap)
     return m_opaque_ap->GetIsBitfield();
   return false;
 }
 
 uint32_t SBTypeMember::GetBitfieldSizeInBits() {
-  if (m_opaque_ap.get())
+  if (m_opaque_ap)
     return m_opaque_ap->GetBitfieldBitSize();
   return 0;
 }
@@ -541,7 +542,7 @@ bool SBTypeMember::GetDescription(lldb::SBStream &description,
                                   lldb::DescriptionLevel description_level) {
   Stream &strm = description.ref();
 
-  if (m_opaque_ap.get()) {
+  if (m_opaque_ap) {
     const uint32_t bit_offset = m_opaque_ap->GetBitOffset();
     const uint32_t byte_offset = bit_offset / 8u;
     const uint32_t byte_bit_offset = bit_offset % 8u;
@@ -571,12 +572,12 @@ void SBTypeMember::reset(TypeMemberImpl *type_member_impl) {
 }
 
 TypeMemberImpl &SBTypeMember::ref() {
-  if (m_opaque_ap.get() == NULL)
+  if (m_opaque_ap == NULL)
     m_opaque_ap.reset(new TypeMemberImpl());
-  return *m_opaque_ap.get();
+  return *m_opaque_ap;
 }
 
-const TypeMemberImpl &SBTypeMember::ref() const { return *m_opaque_ap.get(); }
+const TypeMemberImpl &SBTypeMember::ref() const { return *m_opaque_ap; }
 
 SBTypeMemberFunction::SBTypeMemberFunction() : m_opaque_sp() {}
 
