@@ -9,14 +9,13 @@
 
 #include "lldb/Core/FileLineResolver.h"
 
-// Project includes
-#include "lldb/Core/FileSpecList.h" // for FileSpecList
+#include "lldb/Core/FileSpecList.h"
 #include "lldb/Symbol/CompileUnit.h"
 #include "lldb/Symbol/LineTable.h"
-#include "lldb/Utility/ConstString.h" // for ConstString
-#include "lldb/Utility/Stream.h"      // for Stream
+#include "lldb/Utility/ConstString.h"
+#include "lldb/Utility/Stream.h"
 
-#include <string> // for string
+#include <string>
 
 namespace lldb_private {
 class Address;
@@ -54,8 +53,8 @@ FileLineResolver::SearchCallback(SearchFilter &filter, SymbolContext &context,
           while (file_idx != UINT32_MAX) {
             line_table->FineLineEntriesForFileIndex(file_idx, append,
                                                     m_sc_list);
-            // Get the next file index in case we have multiple file
-            // entries for the same file
+            // Get the next file index in case we have multiple file entries
+            // for the same file
             file_idx = cu->GetSupportFiles().FindFileIndex(file_idx + 1,
                                                            m_file_spec, false);
           }
@@ -68,8 +67,8 @@ FileLineResolver::SearchCallback(SearchFilter &filter, SymbolContext &context,
   return Searcher::eCallbackReturnContinue;
 }
 
-Searcher::Depth FileLineResolver::GetDepth() {
-  return Searcher::eDepthCompUnit;
+lldb::SearchDepth FileLineResolver::GetDepth() {
+  return lldb::eSearchDepthCompUnit;
 }
 
 void FileLineResolver::GetDescription(Stream *s) {
