@@ -1,5 +1,4 @@
-//====-- UserSettingsController.cpp ------------------------------*- C++
-//-*-===//
+//====-- UserSettingsController.cpp ------------------------------*- C++-*-===//
 //
 //                     The LLVM Compiler Infrastructure
 //
@@ -8,37 +7,48 @@
 //
 //===----------------------------------------------------------------------===//
 
-#include <algorithm>
-#include <string.h>
-
-#include "lldb/Core/Error.h"
-#include "lldb/Core/RegularExpression.h"
-#include "lldb/Core/Stream.h"
-#include "lldb/Core/StreamString.h"
 #include "lldb/Core/UserSettingsController.h"
-#include "lldb/Interpreter/CommandInterpreter.h"
+
 #include "lldb/Interpreter/OptionValueProperties.h"
-#include "lldb/Interpreter/OptionValueString.h"
+#include "lldb/Utility/Status.h"
+#include "lldb/Utility/Stream.h"
+
+#include <memory>
+
+namespace lldb_private {
+class CommandInterpreter;
+}
+namespace lldb_private {
+class ConstString;
+}
+namespace lldb_private {
+class ExecutionContext;
+}
+namespace lldb_private {
+class Property;
+}
 
 using namespace lldb;
 using namespace lldb_private;
 
 lldb::OptionValueSP
-Properties::GetPropertyValue(const ExecutionContext *exe_ctx, llvm::StringRef path,
-                             bool will_modify, Error &error) const {
+Properties::GetPropertyValue(const ExecutionContext *exe_ctx,
+                             llvm::StringRef path, bool will_modify,
+                             Status &error) const {
   OptionValuePropertiesSP properties_sp(GetValueProperties());
   if (properties_sp)
     return properties_sp->GetSubValue(exe_ctx, path, will_modify, error);
   return lldb::OptionValueSP();
 }
 
-Error Properties::SetPropertyValue(const ExecutionContext *exe_ctx,
-                                   VarSetOperationType op, llvm::StringRef path,
-  llvm::StringRef value) {
+Status Properties::SetPropertyValue(const ExecutionContext *exe_ctx,
+                                    VarSetOperationType op,
+                                    llvm::StringRef path,
+                                    llvm::StringRef value) {
   OptionValuePropertiesSP properties_sp(GetValueProperties());
   if (properties_sp)
     return properties_sp->SetSubValue(exe_ctx, op, path, value);
-  Error error;
+  Status error;
   error.SetErrorString("no properties");
   return error;
 }
@@ -59,15 +69,16 @@ void Properties::DumpAllDescriptions(CommandInterpreter &interpreter,
     return properties_sp->DumpAllDescriptions(interpreter, strm);
 }
 
-Error Properties::DumpPropertyValue(const ExecutionContext *exe_ctx,
-                                    Stream &strm, llvm::StringRef property_path,
-                                    uint32_t dump_mask) {
+Status Properties::DumpPropertyValue(const ExecutionContext *exe_ctx,
+                                     Stream &strm,
+                                     llvm::StringRef property_path,
+                                     uint32_t dump_mask) {
   OptionValuePropertiesSP properties_sp(GetValueProperties());
   if (properties_sp) {
     return properties_sp->DumpPropertyValue(exe_ctx, strm, property_path,
                                             dump_mask);
   }
-  Error error;
+  Status error;
   error.SetErrorString("empty property list");
   return error;
 }
