@@ -8,7 +8,6 @@
 //===----------------------------------------------------------------------===//
 
 #include "lldb/Core/ValueObjectDynamicValue.h"
-#include "lldb/Core/Scalar.h" // for Scalar, operator!=
 #include "lldb/Core/Value.h"
 #include "lldb/Core/ValueObject.h"
 #include "lldb/Symbol/CompilerType.h"
@@ -17,13 +16,14 @@
 #include "lldb/Target/LanguageRuntime.h"
 #include "lldb/Target/Process.h"
 #include "lldb/Target/Target.h"
-#include "lldb/Utility/DataExtractor.h" // for DataExtractor
+#include "lldb/Utility/DataExtractor.h"
 #include "lldb/Utility/Log.h"
-#include "lldb/Utility/Logging.h" // for GetLogIfAllCategoriesSet
-#include "lldb/Utility/Status.h"  // for Status
-#include "lldb/lldb-types.h"      // for addr_t, offset_t
+#include "lldb/Utility/Logging.h"
+#include "lldb/Utility/Scalar.h"
+#include "lldb/Utility/Status.h"
+#include "lldb/lldb-types.h"
 
-#include <string.h> // for strcmp, size_t
+#include <string.h>
 namespace lldb_private {
 class Declaration;
 }
@@ -92,7 +92,8 @@ ConstString ValueObjectDynamicValue::GetDisplayTypeName() {
 size_t ValueObjectDynamicValue::CalculateNumChildren(uint32_t max) {
   const bool success = UpdateValueIfNeeded(false);
   if (success && m_dynamic_type_info.HasType()) {
-    auto children_count = GetCompilerType().GetNumChildren(true);
+    ExecutionContext exe_ctx(GetExecutionContextRef());
+    auto children_count = GetCompilerType().GetNumChildren(true, &exe_ctx);
     return children_count <= max ? children_count : max;
   } else
     return m_parent->GetNumChildren(max);
@@ -122,8 +123,8 @@ bool ValueObjectDynamicValue::UpdateValue() {
     return false;
   }
 
-  // Setting our type_sp to NULL will route everything back through our
-  // parent which is equivalent to not using dynamic values.
+  // Setting our type_sp to NULL will route everything back through our parent
+  // which is equivalent to not using dynamic values.
   if (m_use_dynamic == lldb::eNoDynamicValues) {
     m_dynamic_type_info.Clear();
     return true;
@@ -173,8 +174,7 @@ bool ValueObjectDynamicValue::UpdateValue() {
   }
 
   // Getting the dynamic value may have run the program a bit, and so marked us
-  // as needing updating, but we really
-  // don't...
+  // as needing updating, but we really don't...
 
   m_update_point.SetUpdated();
 
@@ -192,8 +192,8 @@ bool ValueObjectDynamicValue::UpdateValue() {
   }
 
   // If we don't have a dynamic type, then make ourselves just a echo of our
-  // parent.
-  // Or we could return false, and make ourselves an echo of our parent?
+  // parent. Or we could return false, and make ourselves an echo of our
+  // parent?
   if (!found_dynamic_type) {
     if (m_dynamic_type_info)
       SetValueDidChange(true);
@@ -248,14 +248,14 @@ bool ValueObjectDynamicValue::UpdateValue() {
                 static_cast<void *>(this), GetTypeName().GetCString());
 
   if (m_address.IsValid() && m_dynamic_type_info) {
-    // The variable value is in the Scalar value inside the m_value.
-    // We can point our m_data right to it.
+    // The variable value is in the Scalar value inside the m_value. We can
+    // point our m_data right to it.
     m_error = m_value.GetValueAsData(&exe_ctx, m_data, 0, GetModule().get());
     if (m_error.Success()) {
       if (!CanProvideValue()) {
-        // this value object represents an aggregate type whose
-        // children have values, but this object does not. So we
-        // say we are changed if our location has changed.
+        // this value object represents an aggregate type whose children have
+        // values, but this object does not. So we say we are changed if our
+        // location has changed.
         SetValueDidChange(m_value.GetValueType() != old_value.GetValueType() ||
                           m_value.GetScalar() != old_value.GetScalar());
       }
@@ -287,13 +287,11 @@ bool ValueObjectDynamicValue::SetValueFromCString(const char *value_str,
     return false;
   }
 
-  // if we are at an offset from our parent, in order to set ourselves correctly
-  // we would need
-  // to change the new value so that it refers to the correct dynamic type. we
-  // choose not to deal
-  // with that - if anything more than a value overwrite is required, you should
-  // be using the
-  // expression parser instead of the value editing facility
+  // if we are at an offset from our parent, in order to set ourselves
+  // correctly we would need to change the new value so that it refers to the
+  // correct dynamic type. we choose not to deal with that - if anything more
+  // than a value overwrite is required, you should be using the expression
+  // parser instead of the value editing facility
   if (my_value != parent_value) {
     // but NULL'ing out a value should always be allowed
     if (strcmp(value_str, "0")) {
@@ -322,13 +320,11 @@ bool ValueObjectDynamicValue::SetData(DataExtractor &data, Status &error) {
     return false;
   }
 
-  // if we are at an offset from our parent, in order to set ourselves correctly
-  // we would need
-  // to change the new value so that it refers to the correct dynamic type. we
-  // choose not to deal
-  // with that - if anything more than a value overwrite is required, you should
-  // be using the
-  // expression parser instead of the value editing facility
+  // if we are at an offset from our parent, in order to set ourselves
+  // correctly we would need to change the new value so that it refers to the
+  // correct dynamic type. we choose not to deal with that - if anything more
+  // than a value overwrite is required, you should be using the expression
+  // parser instead of the value editing facility
   if (my_value != parent_value) {
     // but NULL'ing out a value should always be allowed
     lldb::offset_t offset = 0;
