@@ -312,7 +312,7 @@ static bool DumpUTFBufferToStream(
       utf8_data_end_ptr = utf8_data_ptr + utf8_data_buffer_sp->GetByteSize();
       ConvertFunction(&data_ptr, data_end_ptr, &utf8_data_ptr,
                       utf8_data_end_ptr, llvm::lenientConversion);
-      if (false == zero_is_terminator)
+      if (!zero_is_terminator)
         utf8_data_end_ptr = utf8_data_ptr;
       // needed because the ConvertFunction will change the value of the
       // data_ptr.
