@@ -10,10 +10,6 @@
 #include "lldb/DataFormatters/TypeCategory.h"
 #include "lldb/Target/Language.h"
 
-// C Includes
-// C++ Includes
-// Other libraries and framework includes
-// Project includes
 
 using namespace lldb;
 using namespace lldb_private;
@@ -36,23 +32,8 @@ TypeCategoryImpl::TypeCategoryImpl(
 static bool IsApplicable(lldb::LanguageType category_lang,
                          lldb::LanguageType valobj_lang) {
   switch (category_lang) {
-  // these are not languages that LLDB would ordinarily deal with
-  // only allow an exact equality here, since we really don't know
-  // any better
-  case eLanguageTypeAda83:
-  case eLanguageTypeCobol74:
-  case eLanguageTypeCobol85:
-  case eLanguageTypeFortran77:
-  case eLanguageTypeFortran90:
-  case eLanguageTypePascal83:
-  case eLanguageTypeModula2:
-  case eLanguageTypeJava:
-  case eLanguageTypeAda95:
-  case eLanguageTypeFortran95:
-  case eLanguageTypePLI:
-  case eLanguageTypeUPC:
-  case eLanguageTypeD:
-  case eLanguageTypePython:
+  // Unless we know better, allow only exact equality.
+  default:
     return category_lang == valobj_lang;
 
   // the C family, we consider it as one
@@ -80,7 +61,7 @@ static bool IsApplicable(lldb::LanguageType category_lang,
            valobj_lang == eLanguageTypeC_plus_plus ||
            valobj_lang == eLanguageTypeObjC;
 
-  default:
+  // Categories with unspecified language match everything.
   case eLanguageTypeUnknown:
     return true;
   }
@@ -176,10 +157,7 @@ bool TypeCategoryImpl::Get(ValueObject &valobj,
 
   else /*if (filter_sp.get() && synth.get())*/
   {
-    if (filter_sp->GetRevision() > synth->GetRevision())
-      pick_synth = false;
-    else
-      pick_synth = true;
+    pick_synth = filter_sp->GetRevision() <= synth->GetRevision();
   }
   if (pick_synth) {
     if (regex_synth && reason)
