@@ -13,12 +13,13 @@ using namespace lldb_private;
 
 PipeBase::~PipeBase() = default;
 
-Error PipeBase::OpenAsWriter(llvm::StringRef name, bool child_process_inherit) {
+Status PipeBase::OpenAsWriter(llvm::StringRef name,
+                              bool child_process_inherit) {
   return OpenAsWriterWithTimeout(name, child_process_inherit,
                                  std::chrono::microseconds::zero());
 }
 
-Error PipeBase::Read(void *buf, size_t size, size_t &bytes_read) {
+Status PipeBase::Read(void *buf, size_t size, size_t &bytes_read) {
   return ReadWithTimeout(buf, size, std::chrono::microseconds::zero(),
                          bytes_read);
 }
