@@ -12,7 +12,6 @@
 #include "lldb/Core/Module.h"
 #include "lldb/Core/PluginManager.h"
 #include "lldb/Core/Section.h"
-#include "lldb/Core/State.h"
 #include "lldb/Symbol/ClangASTContext.h"
 #include "lldb/Symbol/ObjectFile.h"
 #include "lldb/Symbol/SymbolVendor.h"
@@ -21,6 +20,7 @@
 #include "lldb/Target/Target.h"
 #include "lldb/Target/Thread.h"
 #include "lldb/Utility/Log.h"
+#include "lldb/Utility/State.h"
 
 #include "DynamicLoaderDarwin.h"
 #include "DynamicLoaderMacOS.h"
@@ -29,9 +29,9 @@ using namespace lldb;
 using namespace lldb_private;
 
 //----------------------------------------------------------------------
-// Create an instance of this class. This function is filled into
-// the plugin info class that gets handed out by the plugin factory and
-// allows the lldb to instantiate an instance of this class.
+// Create an instance of this class. This function is filled into the plugin
+// info class that gets handed out by the plugin factory and allows the lldb to
+// instantiate an instance of this class.
 //----------------------------------------------------------------------
 DynamicLoader *DynamicLoaderMacOS::CreateInstance(Process *process,
                                                   bool force) {
@@ -55,6 +55,7 @@ DynamicLoader *DynamicLoaderMacOS::CreateInstance(Process *process,
       case llvm::Triple::IOS:
       case llvm::Triple::TvOS:
       case llvm::Triple::WatchOS:
+      // NEED_BRIDGEOS_TRIPLE case llvm::Triple::BridgeOS:
         create = triple_ref.getVendor() == llvm::Triple::Apple;
         break;
       default:
@@ -64,7 +65,7 @@ DynamicLoader *DynamicLoaderMacOS::CreateInstance(Process *process,
     }
   }
 
-  if (UseDYLDSPI(process) == false) {
+  if (!UseDYLDSPI(process)) {
     create = false;
   }
 
@@ -78,7 +79,8 @@ DynamicLoader *DynamicLoaderMacOS::CreateInstance(Process *process,
 //----------------------------------------------------------------------
 DynamicLoaderMacOS::DynamicLoaderMacOS(Process *process)
     : DynamicLoaderDarwin(process), m_image_infos_stop_id(UINT32_MAX),
-      m_break_id(LLDB_INVALID_BREAK_ID), m_mutex() {}
+      m_break_id(LLDB_INVALID_BREAK_ID), m_mutex(),
+      m_maybe_image_infos_address(LLDB_INVALID_ADDRESS) {}
 
 //----------------------------------------------------------------------
 // Destructor
@@ -94,16 +96,31 @@ bool DynamicLoaderMacOS::ProcessDidExec() {
   if (m_process) {
     // If we are stopped after an exec, we will have only one thread...
     if (m_process->GetThreadList().GetSize() == 1) {
-      // See if we are stopped at '_dyld_start'
-      ThreadSP thread_sp(m_process->GetThreadList().GetThreadAtIndex(0));
-      if (thread_sp) {
-        lldb::StackFrameSP frame_sp(thread_sp->GetStackFrameAtIndex(0));
-        if (frame_sp) {
-          const Symbol *symbol =
-              frame_sp->GetSymbolContext(eSymbolContextSymbol).symbol;
-          if (symbol) {
-            if (symbol->GetName() == ConstString("_dyld_start"))
-              did_exec = true;
+      // Maybe we still have an image infos address around?  If so see
+      // if that has changed, and if so we have exec'ed.
+      if (m_maybe_image_infos_address != LLDB_INVALID_ADDRESS) {
+        lldb::addr_t image_infos_address = m_process->GetImageInfoAddress();
+        if (image_infos_address != m_maybe_image_infos_address) {
+          // We don't really have to reset this here, since we are going to
+          // call DoInitialImageFetch right away to handle the exec.  But in
+          // case anybody looks at it in the meantime, it can't hurt.
+          m_maybe_image_infos_address = image_infos_address;
+          did_exec = true;
+        }
+      }
+
+      if (!did_exec) {
+        // See if we are stopped at '_dyld_start'
+        ThreadSP thread_sp(m_process->GetThreadList().GetThreadAtIndex(0));
+        if (thread_sp) {
+          lldb::StackFrameSP frame_sp(thread_sp->GetStackFrameAtIndex(0));
+          if (frame_sp) {
+            const Symbol *symbol =
+                frame_sp->GetSymbolContext(eSymbolContextSymbol).symbol;
+            if (symbol) {
+              if (symbol->GetName() == ConstString("_dyld_start"))
+                did_exec = true;
+            }
           }
         }
       }
@@ -144,17 +161,18 @@ void DynamicLoaderMacOS::ClearNotificationBreakpoint() {
 }
 
 //----------------------------------------------------------------------
-// Try and figure out where dyld is by first asking the Process
-// if it knows (which currently calls down in the lldb::Process
-// to get the DYLD info (available on SnowLeopard only). If that fails,
-// then check in the default addresses.
+// Try and figure out where dyld is by first asking the Process if it knows
+// (which currently calls down in the lldb::Process to get the DYLD info
+// (available on SnowLeopard only). If that fails, then check in the default
+// addresses.
 //----------------------------------------------------------------------
 void DynamicLoaderMacOS::DoInitialImageFetch() {
   Log *log(lldb_private::GetLogIfAnyCategoriesSet(LIBLLDB_LOG_DYNAMIC_LOADER));
 
-  // Remove any binaries we pre-loaded in the Target before launching/attaching.
-  // If the same binaries are present in the process, we'll get them from the
-  // shared module cache, we won't need to re-load them from disk.
+  // Remove any binaries we pre-loaded in the Target before
+  // launching/attaching. If the same binaries are present in the process,
+  // we'll get them from the shared module cache, we won't need to re-load them
+  // from disk.
   UnloadAllImages();
 
   StructuredData::ObjectSP all_image_info_json_sp(
@@ -178,15 +196,16 @@ void DynamicLoaderMacOS::DoInitialImageFetch() {
   }
 
   m_dyld_image_infos_stop_id = m_process->GetStopID();
+  m_maybe_image_infos_address = m_process->GetImageInfoAddress();
 }
 
 bool DynamicLoaderMacOS::NeedToDoInitialImageFetch() { return true; }
 
 //----------------------------------------------------------------------
 // Static callback function that gets called when our DYLD notification
-// breakpoint gets hit. We update all of our image infos and then
-// let our super class DynamicLoader class decide if we should stop
-// or not (based on global preference).
+// breakpoint gets hit. We update all of our image infos and then let our super
+// class DynamicLoader class decide if we should stop or not (based on global
+// preference).
 //----------------------------------------------------------------------
 bool DynamicLoaderMacOS::NotifyBreakpointHit(void *baton,
                                              StoppointCallbackContext *context,
@@ -194,11 +213,10 @@ bool DynamicLoaderMacOS::NotifyBreakpointHit(void *baton,
                                              lldb::user_id_t break_loc_id) {
   // Let the event know that the images have changed
   // DYLD passes three arguments to the notification breakpoint.
-  // Arg1: enum dyld_notify_mode mode - 0 = adding, 1 = removing, 2 = remove all
-  // Arg2: unsigned long icount        - Number of shared libraries
-  // added/removed
-  // Arg3: uint64_t mach_headers[]     - Array of load addresses of binaries
-  // added/removed
+  // Arg1: enum dyld_notify_mode mode - 0 = adding, 1 = removing, 2 = remove
+  // all Arg2: unsigned long icount        - Number of shared libraries
+  // added/removed Arg3: uint64_t mach_headers[]     - Array of load addresses
+  // of binaries added/removed
 
   DynamicLoaderMacOS *dyld_instance = (DynamicLoaderMacOS *)baton;
 
@@ -328,8 +346,8 @@ void DynamicLoaderMacOS::AddBinaries(
   }
 }
 
-// Dump the _dyld_all_image_infos members and all current image infos
-// that we have parsed to the file handle provided.
+// Dump the _dyld_all_image_infos members and all current image infos that we
+// have parsed to the file handle provided.
 //----------------------------------------------------------------------
 void DynamicLoaderMacOS::PutToLog(Log *log) const {
   if (log == NULL)
@@ -432,9 +450,9 @@ Status DynamicLoaderMacOS::CanLoadImage() {
     }
   }
 
-  // Default assumption is that it is OK to load images.
-  // Only say that we cannot load images if we find the symbol in libdyld and it
-  // indicates that we cannot.
+  // Default assumption is that it is OK to load images. Only say that we
+  // cannot load images if we find the symbol in libdyld and it indicates that
+  // we cannot.
 
   if (symbol_address != LLDB_INVALID_ADDRESS) {
     {
@@ -445,11 +463,11 @@ Status DynamicLoaderMacOS::CanLoadImage() {
       }
     }
   } else {
-    // If we were unable to find _dyld_global_lock_held in any modules, or it is
-    // not loaded into memory yet, we may be at process startup (sitting 
-    // at _dyld_start) - so we should not allow dlopen calls.
-    // But if we found more than one module then we are clearly past _dyld_start
-    // so in that case we'll default to "it's safe".
+    // If we were unable to find _dyld_global_lock_held in any modules, or it
+    // is not loaded into memory yet, we may be at process startup (sitting  at
+    // _dyld_start) - so we should not allow dlopen calls. But if we found more
+    // than one module then we are clearly past _dyld_start so in that case
+    // we'll default to "it's safe".
     if (num_modules <= 1)
         error.SetErrorString("could not find the dyld library or "
                                        "the dyld lock symbol");
@@ -472,7 +490,9 @@ bool DynamicLoaderMacOS::GetSharedCacheInformation(
       info_dict = info->GetAsDictionary();
     }
 
-    // {"shared_cache_base_address":140735683125248,"shared_cache_uuid":"DDB8D70C-C9A2-3561-B2C8-BE48A4F33F96","no_shared_cache":false,"shared_cache_private_cache":false}
+    // {"shared_cache_base_address":140735683125248,"shared_cache_uuid
+    // ":"DDB8D70C-
+    // C9A2-3561-B2C8-BE48A4F33F96","no_shared_cache":false,"shared_cache_private_cache":false}
 
     if (info_dict && info_dict->HasKey("shared_cache_uuid") &&
         info_dict->HasKey("no_shared_cache") &&
@@ -482,9 +502,8 @@ bool DynamicLoaderMacOS::GetSharedCacheInformation(
       std::string uuid_str =
           info_dict->GetValueForKey("shared_cache_uuid")->GetStringValue();
       if (!uuid_str.empty())
-        uuid.SetFromCString(uuid_str.c_str());
-      if (info_dict->GetValueForKey("no_shared_cache")->GetBooleanValue() ==
-          false)
+        uuid.SetFromStringRef(uuid_str);
+      if (!info_dict->GetValueForKey("no_shared_cache")->GetBooleanValue())
         using_shared_cache = eLazyBoolYes;
       else
         using_shared_cache = eLazyBoolNo;
