@@ -10,10 +10,6 @@
 #ifndef liblldb_Plugins_Process_Windows_DynamicLoaderWindowsDYLD_h_
 #define liblldb_Plugins_Process_Windows_DynamicLoaderWindowsDYLD_h_
 
-// C Includes
-// C++ Includes
-// Other libraries and framework includes
-// Project includes
 #include "lldb/Target/DynamicLoader.h"
 #include "lldb/lldb-forward.h"
 
@@ -34,7 +30,7 @@ public:
 
   void DidAttach() override;
   void DidLaunch() override;
-  Error CanLoadImage() override;
+  Status CanLoadImage() override;
   lldb::ThreadPlanSP GetStepThroughTrampolinePlan(Thread &thread,
                                                   bool stop) override;
 
