@@ -9,25 +9,21 @@
 
 #include "CommunicationKDP.h"
 
-// C Includes
 #include <errno.h>
 #include <limits.h>
 #include <string.h>
 
-// C++ Includes
 
-// Other libraries and framework includes
 #include "lldb/Core/DumpDataExtractor.h"
-#include "lldb/Core/State.h"
 #include "lldb/Host/Host.h"
 #include "lldb/Target/Process.h"
 #include "lldb/Utility/DataBufferHeap.h"
 #include "lldb/Utility/DataExtractor.h"
 #include "lldb/Utility/FileSpec.h"
 #include "lldb/Utility/Log.h"
+#include "lldb/Utility/State.h"
 #include "lldb/Utility/UUID.h"
 
-// Project includes
 #include "ProcessKDPLog.h"
 
 using namespace lldb;
@@ -118,16 +114,14 @@ bool CommunicationKDP::SendRequestAndGetReply(
             }
           } else if (reply_sequence_id > request_sequence_id) {
             // Sequence ID was greater than the sequence ID of the packet we
-            // sent, something
-            // is really wrong...
+            // sent, something is really wrong...
             reply_packet.Clear();
             return false;
           } else {
-            // The reply sequence ID was less than our current packet's sequence
-            // ID
-            // so we should keep trying to get a response because this was a
-            // response
-            // for a previous packet that we must have retried.
+            // The reply sequence ID was less than our current packet's
+            // sequence ID so we should keep trying to get a response because
+            // this was a response for a previous packet that we must have
+            // retried.
           }
         } else {
           // Break and retry sending the packet as we didn't get a response due
@@ -177,7 +171,7 @@ bool CommunicationKDP::GetSequenceMutex(
 
 bool CommunicationKDP::WaitForNotRunningPrivate(
     const std::chrono::microseconds &timeout) {
-  return m_is_running.WaitForValueEqualTo(false, timeout, NULL);
+  return m_is_running.WaitForValueEqualTo(false, timeout);
 }
 
 size_t
@@ -315,9 +309,9 @@ bool CommunicationKDP::CheckForPacket(const uint8_t *src, size_t src_len,
       offset = 2;
       const uint16_t length = packet.GetU16(&offset);
       if (length <= bytes_available) {
-        // We have an entire packet ready, we need to copy the data
-        // bytes into a buffer that will be owned by the packet and
-        // erase the bytes from our communcation buffer "m_bytes"
+        // We have an entire packet ready, we need to copy the data bytes into
+        // a buffer that will be owned by the packet and erase the bytes from
+        // our communcation buffer "m_bytes"
         packet.SetData(DataBufferSP(new DataBufferHeap(&m_bytes[0], length)));
         m_bytes.erase(0, length);
 
@@ -332,8 +326,8 @@ bool CommunicationKDP::CheckForPacket(const uint8_t *src, size_t src_len,
     } break;
 
     default:
-      // Unrecognized reply command byte, erase this byte and try to get back on
-      // track
+      // Unrecognized reply command byte, erase this byte and try to get back
+      // on track
       if (log)
         log->Printf("CommunicationKDP::%s: tossing junk byte: 0x%2.2x",
                     __FUNCTION__, (uint8_t)m_bytes[0]);
@@ -458,7 +452,7 @@ lldb_private::UUID CommunicationKDP::GetUUID() {
   if (uuid_str.size() < 32)
     return uuid;
 
-  if (uuid.SetFromCString(uuid_str.c_str()) == 0) {
+  if (uuid.SetFromStringRef(uuid_str) == 0) {
     UUID invalid_uuid;
     return invalid_uuid;
   }
@@ -469,19 +463,13 @@ lldb_private::UUID CommunicationKDP::GetUUID() {
 bool CommunicationKDP::RemoteIsEFI() {
   if (GetKernelVersion() == NULL)
     return false;
-  if (strncmp(m_kernel_version.c_str(), "EFI", 3) == 0)
-    return true;
-  else
-    return false;
+  return strncmp(m_kernel_version.c_str(), "EFI", 3) == 0;
 }
 
 bool CommunicationKDP::RemoteIsDarwinKernel() {
   if (GetKernelVersion() == NULL)
     return false;
-  if (m_kernel_version.find("Darwin Kernel") != std::string::npos)
-    return true;
-  else
-    return false;
+  return m_kernel_version.find("Darwin Kernel") != std::string::npos;
 }
 
 lldb::addr_t CommunicationKDP::GetLoadAddress() {
@@ -1208,8 +1196,8 @@ uint32_t CommunicationKDP::SendRequestReadRegisters(uint32_t cpu,
       if (src) {
         ::memcpy(dst, src, bytes_to_copy);
         error.Clear();
-        // Return the number of bytes we could have returned regardless if
-        // we copied them or not, just so we know when things don't match up
+        // Return the number of bytes we could have returned regardless if we
+        // copied them or not, just so we know when things don't match up
         return src_len;
       }
     }
@@ -1264,9 +1252,7 @@ bool CommunicationKDP::SendRequestResume() {
   request_packet.PutHex32(GetCPUMask());
 
   DataExtractor reply_packet;
-  if (SendRequestAndGetReply(command, request_packet, reply_packet))
-    return true;
-  return false;
+  return SendRequestAndGetReply(command, request_packet, reply_packet);
 }
 
 bool CommunicationKDP::SendRequestBreakpoint(bool set, addr_t addr) {
@@ -1299,7 +1285,5 @@ bool CommunicationKDP::SendRequestSuspend() {
   const uint32_t command_length = 8;
   MakeRequestPacketHeader(command, request_packet, command_length);
   DataExtractor reply_packet;
-  if (SendRequestAndGetReply(command, request_packet, reply_packet))
-    return true;
-  return false;
+  return SendRequestAndGetReply(command, request_packet, reply_packet);
 }
