@@ -94,9 +94,9 @@ const char *SymbolVendorMacOSX::GetPluginDescriptionStatic() {
 //----------------------------------------------------------------------
 // CreateInstance
 //
-// Platforms can register a callback to use when creating symbol
-// vendors to allow for complex debug information file setups, and to
-// also allow for finding separate debug information files.
+// Platforms can register a callback to use when creating symbol vendors to
+// allow for complex debug information file setups, and to also allow for
+// finding separate debug information files.
 //----------------------------------------------------------------------
 SymbolVendor *
 SymbolVendorMacOSX::CreateInstance(const lldb::ModuleSP &module_sp,
@@ -130,14 +130,14 @@ SymbolVendorMacOSX::CreateInstance(const lldb::ModuleSP &module_sp,
         "SymbolVendorMacOSX::CreateInstance (module = %s) locate dSYM",
         module_sp->GetFileSpec().GetPath().c_str());
 
-    // First check to see if the module has a symbol file in mind already.
-    // If it does, then we MUST use that.
+    // First check to see if the module has a symbol file in mind already. If
+    // it does, then we MUST use that.
     FileSpec dsym_fspec(module_sp->GetSymbolFileFileSpec());
 
     ObjectFileSP dsym_objfile_sp;
     if (!dsym_fspec) {
-      // No symbol file was specified in the module, lets try and find
-      // one ourselves.
+      // No symbol file was specified in the module, lets try and find one
+      // ourselves.
       FileSpec file_spec = obj_file->GetFileSpec();
       if (!file_spec)
         file_spec = module_sp->GetFileSpec();
@@ -153,9 +153,10 @@ SymbolVendorMacOSX::CreateInstance(const lldb::ModuleSP &module_sp,
     if (dsym_fspec) {
       DataBufferSP dsym_file_data_sp;
       lldb::offset_t dsym_file_data_offset = 0;
-      dsym_objfile_sp = ObjectFile::FindPlugin(
-          module_sp, &dsym_fspec, 0, dsym_fspec.GetByteSize(),
-          dsym_file_data_sp, dsym_file_data_offset);
+      dsym_objfile_sp =
+          ObjectFile::FindPlugin(module_sp, &dsym_fspec, 0,
+                                 FileSystem::Instance().GetByteSize(dsym_fspec),
+                                 dsym_file_data_sp, dsym_file_data_offset);
       if (UUIDsMatch(module_sp.get(), dsym_objfile_sp.get(), feedback_strm)) {
         // We need a XML parser if we hope to parse a plist...
         if (XMLDocument::XMLEnabled()) {
@@ -172,31 +173,15 @@ SymbolVendorMacOSX::CreateInstance(const lldb::ModuleSP &module_sp,
                   resources[strlen("/Contents/Resources/")] = '\0';
                   snprintf(dsym_uuid_plist_path, sizeof(dsym_uuid_plist_path),
                            "%s%s.plist", dsym_path, uuid_str.c_str());
-                  FileSpec dsym_uuid_plist_spec(dsym_uuid_plist_path, false);
-                  if (dsym_uuid_plist_spec.Exists()) {
+                  FileSpec dsym_uuid_plist_spec(dsym_uuid_plist_path);
+                  if (FileSystem::Instance().Exists(dsym_uuid_plist_spec)) {
                     ApplePropertyList plist(dsym_uuid_plist_path);
                     if (plist) {
                       std::string DBGBuildSourcePath;
                       std::string DBGSourcePath;
 
-                      plist.GetValueAsString("DBGBuildSourcePath",
-                                             DBGBuildSourcePath);
-                      plist.GetValueAsString("DBGSourcePath", DBGSourcePath);
-                      if (!DBGBuildSourcePath.empty() &&
-                          !DBGSourcePath.empty()) {
-                        if (DBGSourcePath[0] == '~') {
-                          FileSpec resolved_source_path(DBGSourcePath.c_str(),
-                                                        true);
-                          DBGSourcePath = resolved_source_path.GetPath();
-                        }
-                        module_sp->GetSourceMappingList().Append(
-                            ConstString(DBGBuildSourcePath),
-                            ConstString(DBGSourcePath), true);
-                      }
-
                       // DBGSourcePathRemapping is a dictionary in the plist
-                      // with
-                      // keys which are DBGBuildSourcePath file paths and
+                      // with keys which are DBGBuildSourcePath file paths and
                       // values which are DBGSourcePath file paths
 
                       StructuredData::ObjectSP plist_sp =
@@ -208,17 +193,14 @@ SymbolVendorMacOSX::CreateInstance(const lldb::ModuleSP &module_sp,
                               ->GetValueForKey("DBGSourcePathRemapping")
                               ->GetAsDictionary()) {
 
-                        // In an early version of DBGSourcePathRemapping, the
-                        // DBGSourcePath
-                        // values were incorrect.  If we have a newer style
-                        // DBGSourcePathRemapping, there will be a DBGVersion
-                        // key in the plist with version 2 or higher.
+                        // If DBGVersion 1 or DBGVersion missing, ignore DBGSourcePathRemapping.
+                        // If DBGVersion 2, strip last two components of path remappings from
+                        //                  entries to fix an issue with a specific set of
+                        //                  DBGSourcePathRemapping entries that lldb worked
+                        //                  with.
+                        // If DBGVersion 3, trust & use the source path remappings as-is.
                         //
-                        // If this is an old style DBGSourcePathRemapping,
-                        // ignore the
-                        // value half of the key-value remappings and use reuse
-                        // the original
-                        // gloal DBGSourcePath string.
+
                         bool new_style_source_remapping_dictionary = false;
                         bool do_truncate_remapping_names = false;
                         std::string original_DBGSourcePath_value =
@@ -255,26 +237,29 @@ SymbolVendorMacOSX::CreateInstance(const lldb::ModuleSP &module_sp,
                                 // object is DBGSourcePath
                                 std::string DBGSourcePath =
                                     object->GetStringValue();
-                                if (new_style_source_remapping_dictionary ==
-                                        false &&
+                                if (!new_style_source_remapping_dictionary &&
                                     !original_DBGSourcePath_value.empty()) {
                                   DBGSourcePath = original_DBGSourcePath_value;
                                 }
                                 if (DBGSourcePath[0] == '~') {
                                   FileSpec resolved_source_path(
-                                      DBGSourcePath.c_str(), true);
+                                      DBGSourcePath.c_str());
+                                  FileSystem::Instance().Resolve(
+                                      resolved_source_path);
                                   DBGSourcePath =
                                       resolved_source_path.GetPath();
                                 }
                                 module_sp->GetSourceMappingList().Append(
                                     key, ConstString(DBGSourcePath), true);
-                                // With version 2 of DBGSourcePathRemapping, we can chop off the
-                                // last two filename parts from the source remapping and get a
-                                // more general source remapping that still works.  Add this as
-                                // another option in addition to the full source path remap.
+                                // With version 2 of DBGSourcePathRemapping, we
+                                // can chop off the last two filename parts
+                                // from the source remapping and get a more
+                                // general source remapping that still works.
+                                // Add this as another option in addition to
+                                // the full source path remap.
                                 if (do_truncate_remapping_names) {
-                                  FileSpec build_path(key.AsCString(), false);
-                                  FileSpec source_path(DBGSourcePath.c_str(), false);
+                                  FileSpec build_path(key.AsCString());
+                                  FileSpec source_path(DBGSourcePath.c_str());
                                   build_path.RemoveLastPathComponent();
                                   build_path.RemoveLastPathComponent();
                                   source_path.RemoveLastPathComponent();
@@ -287,6 +272,24 @@ SymbolVendorMacOSX::CreateInstance(const lldb::ModuleSP &module_sp,
                               return true;
                             });
                       }
+
+                      // If we have a DBGBuildSourcePath + DBGSourcePath pair,
+                      // append those to the source path remappings.
+
+                      plist.GetValueAsString("DBGBuildSourcePath",
+                                             DBGBuildSourcePath);
+                      plist.GetValueAsString("DBGSourcePath", DBGSourcePath);
+                      if (!DBGBuildSourcePath.empty() &&
+                          !DBGSourcePath.empty()) {
+                        if (DBGSourcePath[0] == '~') {
+                          FileSpec resolved_source_path(DBGSourcePath.c_str());
+                          FileSystem::Instance().Resolve(resolved_source_path);
+                          DBGSourcePath = resolved_source_path.GetPath();
+                        }
+                        module_sp->GetSourceMappingList().Append(
+                            ConstString(DBGBuildSourcePath),
+                            ConstString(DBGSourcePath), true);
+                      }
                     }
                   }
                 }
@@ -300,9 +303,9 @@ SymbolVendorMacOSX::CreateInstance(const lldb::ModuleSP &module_sp,
       }
     }
 
-    // Just create our symbol vendor using the current objfile as this is either
-    // an executable with no dSYM (that we could locate), an executable with
-    // a dSYM that has a UUID that doesn't match.
+    // Just create our symbol vendor using the current objfile as this is
+    // either an executable with no dSYM (that we could locate), an executable
+    // with a dSYM that has a UUID that doesn't match.
     symbol_vendor->AddSymbolFileRepresentation(obj_file->shared_from_this());
   }
   return symbol_vendor;
