@@ -7,12 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 
-// C Includes
-// C++ Includes
-// Other libraries and framework includes
-// Project includes
 #include "lldb/Target/LanguageRuntime.h"
-#include "Plugins/Language/CPlusPlus/CPlusPlusLanguage.h"
 #include "Plugins/Language/ObjC/ObjCLanguage.h"
 #include "lldb/Core/PluginManager.h"
 #include "lldb/Core/SearchFilter.h"
@@ -90,7 +85,8 @@ ExceptionSearchFilter::DoCopyForBreakpoint(Breakpoint &breakpoint) {
 }
 
 SearchFilter *ExceptionSearchFilter::CreateFromStructuredData(
-    Target &target, const StructuredData::Dictionary &data_dict, Error &error) {
+    Target &target, const StructuredData::Dictionary &data_dict,
+    Status &error) {
   SearchFilter *result = nullptr;
   return result;
 }
@@ -125,11 +121,11 @@ public:
       return eCallbackReturnStop;
   }
 
-  Searcher::Depth GetDepth() override {
+  lldb::SearchDepth GetDepth() override {
     if (SetActualResolver())
       return m_actual_resolver_sp->GetDepth();
     else
-      return eDepthTarget;
+      return lldb::eSearchDepthTarget;
   }
 
   void GetDescription(Stream *s) override {
