@@ -7,10 +7,6 @@
 //
 //===----------------------------------------------------------------------===//
 
-// C Includes
-// C++ Includes
-// Other libraries and framework includes
-// Project includes
 #include "lldb/Target/ThreadPlanStepOut.h"
 #include "lldb/Breakpoint/Breakpoint.h"
 #include "lldb/Core/Value.h"
@@ -48,32 +44,47 @@ ThreadPlanStepOut::ThreadPlanStepOut(
       m_return_addr(LLDB_INVALID_ADDRESS), m_stop_others(stop_others),
       m_immediate_step_from_function(nullptr),
       m_calculate_return_value(gather_return_value) {
+  Log *log(lldb_private::GetLogIfAllCategoriesSet(LIBLLDB_LOG_STEP));
   SetFlagsToDefault();
   SetupAvoidNoDebug(step_out_avoids_code_without_debug_info);
 
   m_step_from_insn = m_thread.GetRegisterContext()->GetPC(0);
 
-  StackFrameSP return_frame_sp(m_thread.GetStackFrameAtIndex(frame_idx + 1));
+  uint32_t return_frame_index = frame_idx + 1;
+  StackFrameSP return_frame_sp(
+      m_thread.GetStackFrameAtIndex(return_frame_index));
   StackFrameSP immediate_return_from_sp(
       m_thread.GetStackFrameAtIndex(frame_idx));
 
   if (!return_frame_sp || !immediate_return_from_sp)
     return; // we can't do anything here.  ValidatePlan() will return false.
 
+  // While stepping out, behave as-if artificial frames are not present.
+  while (return_frame_sp->IsArtificial()) {
+    m_stepped_past_frames.push_back(return_frame_sp);
+
+    ++return_frame_index;
+    return_frame_sp = m_thread.GetStackFrameAtIndex(return_frame_index);
+
+    // We never expect to see an artificial frame without a regular ancestor.
+    // If this happens, log the issue and defensively refuse to step out.
+    if (!return_frame_sp) {
+      LLDB_LOG(log, "Can't step out of frame with artificial ancestors");
+      return;
+    }
+  }
+
   m_step_out_to_id = return_frame_sp->GetStackID();
   m_immediate_step_from_id = immediate_return_from_sp->GetStackID();
 
-  // If the frame directly below the one we are returning to is inlined, we have
-  // to be
-  // a little more careful.  It is non-trivial to determine the real "return
-  // code address" for
-  // an inlined frame, so we have to work our way to that frame and then step
-  // out.
-  if (immediate_return_from_sp && immediate_return_from_sp->IsInlined()) {
+  // If the frame directly below the one we are returning to is inlined, we
+  // have to be a little more careful.  It is non-trivial to determine the real
+  // "return code address" for an inlined frame, so we have to work our way to
+  // that frame and then step out.
+  if (immediate_return_from_sp->IsInlined()) {
     if (frame_idx > 0) {
       // First queue a plan that gets us to this inlined frame, and when we get
-      // there we'll queue a second
-      // plan that walks us out of this frame.
+      // there we'll queue a second plan that walks us out of this frame.
       m_step_out_to_inline_plan_sp.reset(new ThreadPlanStepOut(
           m_thread, nullptr, false, stop_others, eVoteNoOpinion, eVoteNoOpinion,
           frame_idx - 1, eLazyBoolNo, continue_to_next_branch));
@@ -81,11 +92,11 @@ ThreadPlanStepOut::ThreadPlanStepOut(
           ->SetShouldStopHereCallbacks(nullptr, nullptr);
       m_step_out_to_inline_plan_sp->SetPrivate(true);
     } else {
-      // If we're already at the inlined frame we're stepping through, then just
-      // do that now.
+      // If we're already at the inlined frame we're stepping through, then
+      // just do that now.
       QueueInlinedStepPlan(false);
     }
-  } else if (return_frame_sp) {
+  } else {
     // Find the return address and set a breakpoint there:
     // FIXME - can we do this more securely if we know first_insn?
 
@@ -118,7 +129,10 @@ ThreadPlanStepOut::ThreadPlanStepOut(
     Breakpoint *return_bp = m_thread.CalculateTarget()
                                 ->CreateBreakpoint(m_return_addr, true, false)
                                 .get();
+
     if (return_bp != nullptr) {
+      if (return_bp->IsHardware() && !return_bp->HasResolvedLocations())
+        m_could_not_resolve_hw_bp = true;
       return_bp->SetThreadID(m_thread.GetID());
       m_return_bp_id = return_bp->GetID();
       return_bp->SetBreakpointKind("step-out");
@@ -201,24 +215,40 @@ void ThreadPlanStepOut::GetDescription(Stream *s,
         s->Printf(" using breakpoint site %d", m_return_bp_id);
     }
   }
+
+  s->Printf("\n");
+  for (StackFrameSP frame_sp : m_stepped_past_frames) {
+    s->Printf("Stepped out past: ");
+    frame_sp->DumpUsingSettingsFormat(s);
+  }
 }
 
 bool ThreadPlanStepOut::ValidatePlan(Stream *error) {
   if (m_step_out_to_inline_plan_sp)
     return m_step_out_to_inline_plan_sp->ValidatePlan(error);
-  else if (m_step_through_inline_plan_sp)
+
+  if (m_step_through_inline_plan_sp)
     return m_step_through_inline_plan_sp->ValidatePlan(error);
-  else if (m_return_bp_id == LLDB_INVALID_BREAK_ID) {
+
+  if (m_could_not_resolve_hw_bp) {
+    if (error)
+      error->PutCString(
+          "Could not create hardware breakpoint for thread plan.");
+    return false;
+  }
+
+  if (m_return_bp_id == LLDB_INVALID_BREAK_ID) {
     if (error)
       error->PutCString("Could not create return address breakpoint.");
     return false;
-  } else
-    return true;
+  }
+
+  return true;
 }
 
 bool ThreadPlanStepOut::DoPlanExplainsStop(Event *event_ptr) {
-  // If the step out plan is done, then we just need to step through the inlined
-  // frame.
+  // If the step out plan is done, then we just need to step through the
+  // inlined frame.
   if (m_step_out_to_inline_plan_sp) {
     return m_step_out_to_inline_plan_sp->MischiefManaged();
   } else if (m_step_through_inline_plan_sp) {
@@ -233,15 +263,14 @@ bool ThreadPlanStepOut::DoPlanExplainsStop(Event *event_ptr) {
   }
 
   // We don't explain signals or breakpoints (breakpoints that handle stepping
-  // in or
-  // out will be handled by a child plan.
+  // in or out will be handled by a child plan.
 
   StopInfoSP stop_info_sp = GetPrivateStopInfo();
   if (stop_info_sp) {
     StopReason reason = stop_info_sp->GetStopReason();
     if (reason == eStopReasonBreakpoint) {
-      // If this is OUR breakpoint, we're fine, otherwise we don't know why this
-      // happened...
+      // If this is OUR breakpoint, we're fine, otherwise we don't know why
+      // this happened...
       BreakpointSiteSP site_sp(
           m_thread.GetProcess()->GetBreakpointSiteList().FindByID(
               stop_info_sp->GetValue()));
@@ -261,18 +290,17 @@ bool ThreadPlanStepOut::DoPlanExplainsStop(Event *event_ptr) {
         }
 
         if (done) {
-          if (InvokeShouldStopHereCallback(eFrameCompareOlder)) {
+          if (InvokeShouldStopHereCallback(eFrameCompareOlder, m_status)) {
             CalculateReturnValue();
             SetPlanComplete();
           }
         }
 
         // If there was only one owner, then we're done.  But if we also hit
-        // some
-        // user breakpoint on our way out, we should mark ourselves as done, but
-        // also not claim to explain the stop, since it is more important to
-        // report
-        // the user breakpoint than the step out completion.
+        // some user breakpoint on our way out, we should mark ourselves as
+        // done, but also not claim to explain the stop, since it is more
+        // important to report the user breakpoint than the step out
+        // completion.
 
         if (site_sp->GetNumberOfOwners() == 1)
           return true;
@@ -320,17 +348,16 @@ bool ThreadPlanStepOut::ShouldStop(Event *event_ptr) {
     done = !(frame_zero_id < m_step_out_to_id);
   }
 
-  // The normal step out computations think we are done, so all we need to do is
-  // consult the ShouldStopHere,
-  // and we are done.
+  // The normal step out computations think we are done, so all we need to do
+  // is consult the ShouldStopHere, and we are done.
 
   if (done) {
-    if (InvokeShouldStopHereCallback(eFrameCompareOlder)) {
+    if (InvokeShouldStopHereCallback(eFrameCompareOlder, m_status)) {
       CalculateReturnValue();
       SetPlanComplete();
     } else {
       m_step_out_further_plan_sp =
-          QueueStepOutFromHerePlan(m_flags, eFrameCompareOlder);
+          QueueStepOutFromHerePlan(m_flags, eFrameCompareOlder, m_status);
       done = false;
     }
   }
@@ -377,8 +404,7 @@ bool ThreadPlanStepOut::MischiefManaged() {
     // I also check the stack depth, since if we've blown past the breakpoint
     // for some
     // reason and we're now stopping for some other reason altogether, then
-    // we're done
-    // with this step out operation.
+    // we're done with this step out operation.
 
     Log *log(lldb_private::GetLogIfAllCategoriesSet(LIBLLDB_LOG_STEP));
     if (log)
@@ -397,10 +423,8 @@ bool ThreadPlanStepOut::MischiefManaged() {
 
 bool ThreadPlanStepOut::QueueInlinedStepPlan(bool queue_now) {
   // Now figure out the range of this inlined block, and set up a "step through
-  // range"
-  // plan for that.  If we've been provided with a context, then use the block
-  // in that
-  // context.
+  // range" plan for that.  If we've been provided with a context, then use the
+  // block in that context.
   StackFrameSP immediate_return_from_sp(m_thread.GetStackFrameAtIndex(0));
   if (!immediate_return_from_sp)
     return false;
@@ -477,8 +501,8 @@ void ThreadPlanStepOut::CalculateReturnValue() {
 }
 
 bool ThreadPlanStepOut::IsPlanStale() {
-  // If we are still lower on the stack than the frame we are returning to, then
-  // there's something for us to do.  Otherwise, we're stale.
+  // If we are still lower on the stack than the frame we are returning to,
+  // then there's something for us to do.  Otherwise, we're stale.
 
   StackID frame_zero_id = m_thread.GetStackFrameAtIndex(0)->GetStackID();
   return !(frame_zero_id < m_step_out_to_id);
