@@ -13,7 +13,7 @@
 #include "lldb/Utility/Endian.h"
 
 #include "llvm/Support/Endian.h"
-#include "llvm/Support/ErrorHandling.h" // for llvm_unreachable
+#include "llvm/Support/ErrorHandling.h"
 #include "llvm/Support/MathExtras.h"
 
 #include <cassert>
