@@ -19,14 +19,14 @@ using namespace lldb_private;
 void lldb_private::lldb_assert(bool expression, const char *expr_text,
                                const char *func, const char *file,
                                unsigned int line) {
-  if (expression)
-    ;
-  else {
-    errs() << format("Assertion failed: (%s), function %s, file %s, line %u\n",
-                     expr_text, func, file, line);
-    errs() << "backtrace leading to the failure:\n";
-    llvm::sys::PrintStackTrace(errs());
-    errs() << "please file a bug report against lldb reporting this failure "
-              "log, and as many details as possible\n";
-  }
+  if (LLVM_LIKELY(expression))
+    return;
+
+  errs() << format("Assertion failed: (%s), function %s, file %s, line %u\n",
+                   expr_text, func, file, line);
+  errs() << "backtrace leading to the failure:\n";
+  llvm::sys::PrintStackTrace(errs());
+  errs() << "please file a bug report against lldb reporting this failure "
+            "log, and as many details as possible\n";
+  abort();
 }
