@@ -9,13 +9,16 @@
 
 // Overview:    CMICmdCmdGdbThread      interface.
 //
-//              To implement new MI commands derive a new command class from the command base
-//              class. To enable the new command for interpretation add the new command class
+//              To implement new MI commands derive a new command class from the
+//              command base
+//              class. To enable the new command for interpretation add the new
+//              command class
 //              to the command factory. The files of relevance are:
 //                  MICmdCommands.cpp
 //                  MICmdBase.h / .cpp
 //                  MICmdCmd.h / .cpp
-//              For an introduction to adding a new command see CMICmdCmdSupportInfoMiCmdQuery
+//              For an introduction to adding a new command see
+//              CMICmdCmdSupportInfoMiCmdQuery
 //              command class as an example.
 
 #pragma once
@@ -23,26 +26,26 @@
 // In-house headers:
 #include "MICmdBase.h"
 
-//++ ============================================================================
+//++
+//============================================================================
 // Details: MI command class. MI commands derived from the command base class.
 //          *this class implements GDB command "thread".
 //--
-class CMICmdCmdGdbThread : public CMICmdBase
-{
-    // Statics:
-  public:
-    // Required by the CMICmdFactory when registering *this command
-    static CMICmdBase *CreateSelf();
+class CMICmdCmdGdbThread : public CMICmdBase {
+  // Statics:
+public:
+  // Required by the CMICmdFactory when registering *this command
+  static CMICmdBase *CreateSelf();
 
-    // Methods:
-  public:
-    /* ctor */ CMICmdCmdGdbThread();
+  // Methods:
+public:
+  /* ctor */ CMICmdCmdGdbThread();
 
-    // Overridden:
-  public:
-    // From CMICmdInvoker::ICmd
-    bool Execute() override;
-    bool Acknowledge() override;
-    // From CMICmnBase
-    /* dtor */ ~CMICmdCmdGdbThread() override;
+  // Overridden:
+public:
+  // From CMICmdInvoker::ICmd
+  bool Execute() override;
+  bool Acknowledge() override;
+  // From CMICmnBase
+  /* dtor */ ~CMICmdCmdGdbThread() override;
 };
