@@ -9,7 +9,7 @@
 
 // Third party headers
 #include "assert.h"
-#include <inttypes.h> // For PRIx64
+#include <inttypes.h>
 
 // In-house headers:
 #include "MICmnResources.h"
@@ -78,7 +78,7 @@ const CMICmnResources::SRsrcTextData
          "and a custom plugin.\nThe custom plugin is not necessary to operate "
          "the MI Driver."},
         {IDE_MI_APP_ARG_USAGE, "\nMI driver usage:\n\n\tlldb-mi [--longOption] "
-                               "[-s hortOption] [executeable]\n\n[] = optional "
+                               "[-s hortOption] [executable]\n\n[] = optional "
                                "argument."},
         {IDE_MI_APP_ARG_HELP, "-h\n--help\n\tPrints out usage information for "
                               "the MI debugger. Exit the MI\n\tDriver "
@@ -110,6 +110,8 @@ const CMICmnResources::SRsrcTextData
         {IDE_MI_APP_ARG_EXECUTABLE, "executable (NOT IMPLEMENTED)\n\tThe file "
                                     "path to the executable i.e. '\"C:\\My "
                                     "Dev\\foo.exe\"'."},
+        {IDE_MI_APP_ARG_SYNCHRONOUS, "--synchronous\n\tBlock until each command "
+                                     "has finished executing.\n\tUsed for testing only."},
         {IDS_STDIN_ERR_INVALID_PROMPT,
          "Stdin. Invalid prompt description '%s'"},
         {IDS_STDIN_ERR_THREAD_CREATION_FAILED,
@@ -437,6 +439,8 @@ const CMICmnResources::SRsrcTextData
         {IDS_CMD_ERR_INFO_PRINTFN_FAILED, "The request '%s' failed."},
         {IDS_CMD_ERR_GDBSET_OPT_TARGETASYNC,
          "'target-async' expects \"on\" or \"off\""},
+        {IDS_CMD_ERR_GDBSET_OPT_BREAKPOINT,
+         "'breakpoint' expects \"pending on\" or \"pending off\""},
         {IDS_CMD_ERR_GDBSET_OPT_SOLIBSEARCHPATH,
          "'solib-search-path' requires at least one argument"},
         {IDS_CMD_ERR_GDBSET_OPT_PRINT_BAD_ARGS,
@@ -447,9 +451,13 @@ const CMICmnResources::SRsrcTextData
          "'print' expects option-name and \"on\" or \"off\""},
         {IDS_CMD_ERR_GDBSHOW_OPT_PRINT_UNKNOWN_OPTION,
          "'print' error. The option '%s' not found"},
+        {IDS_CMD_ERR_GDBSHOW_OPT_BREAKPOINT_BAD_ARGS,
+        "'breakpoint' expects option-name"},
+        {IDS_CMD_ERR_GDBSHOW_OPT_BREAKPOINT_UNKNOWN_OPTION,
+        "'breakpoint' error. The option '%s' not found"},
         {IDS_CMD_ERR_EXPR_INVALID, "Failed to evaluate expression: %s"},
         {IDS_CMD_ERR_ATTACH_FAILED,
-         "Command '%s'. Attach to processs failed: %s"},
+         "Command '%s'. Attach to process failed: %s"},
         {IDS_CMD_ERR_ATTACH_BAD_ARGS,
          "Command '%s'. Must specify either a PID or a Name"}};
 
