@@ -10,12 +10,12 @@
 // Third party headers
 #include "llvm/Support/Compiler.h"
 #include <cstdlib>
-#include <inttypes.h> // for PRIx8
-#include <limits.h>   // for ULONG_MAX
-#include <memory>     // std::unique_ptr
-#include <sstream>    // std::stringstream
-#include <stdarg.h>   // va_list, va_start, var_end
-#include <string.h>   // for strncmp
+#include <inttypes.h>
+#include <limits.h>
+#include <memory>
+#include <sstream>
+#include <stdarg.h>
+#include <string.h>
 
 // In-house headers:
 #include "MIUtilString.h"
@@ -378,10 +378,7 @@ bool CMIUtilString::IsNumber() const {
     return false;
 
   const size_t nPos = find_first_not_of("-.0123456789");
-  if (nPos != std::string::npos)
-    return false;
-
-  return true;
+  return nPos == std::string::npos;
 }
 
 //++
@@ -399,10 +396,7 @@ bool CMIUtilString::IsHexadecimalNumber() const {
 
   // Skip '0x..' prefix
   const size_t nPos = find_first_not_of("01234567890ABCDEFabcedf", 2);
-  if (nPos != std::string::npos)
-    return false;
-
-  return true;
+  return nPos == std::string::npos;
 }
 
 //++
@@ -419,10 +413,7 @@ bool CMIUtilString::ExtractNumber(MIint64 &vwrNumber) const {
   vwrNumber = 0;
 
   if (!IsNumber()) {
-    if (ExtractNumberFromHexadecimal(vwrNumber))
-      return true;
-
-    return false;
+    return ExtractNumberFromHexadecimal(vwrNumber);
   }
 
   std::stringstream ss(const_cast<CMIUtilString &>(*this));
@@ -639,10 +630,7 @@ bool CMIUtilString::IsQuoted() const {
     return false;
 
   const size_t nLen = length();
-  if ((nLen > 0) && (at(nLen - 1) != cQuote))
-    return false;
-
-  return true;
+  return !((nLen > 0) && (at(nLen - 1) != cQuote));
 }
 
 //++
